@@ -18,10 +18,12 @@
 //REFERENCES:
 //
 //		Hints from Ted Jensen's Tutorial on Pointers and Arrays in C -
-//			- Chapter 9: Pointers and Dynamic Allocation of Memory - improvement so that the elements of a matrix are in a contiguous memory location.
+//			- Chapter 9: Pointers and Dynamic Allocation of Memory - improvement so that the elements of a matrix are in a contiguous memory location:
+//			-> http://pweb.netcom.com/~tjensen/ptr/ (broken link? A working link might be: https://pdos.csail.mit.edu/6.828/2014/readings/pointers.pdf)
 //
 //		Hints from C++ FAQ LITE by Marshall Cline -
-//			- Section [13] - Operator overloading, article [13.12] - advice about the () operator for matrices.
+//			- Section [13] - Operator overloading, article [13.12] - advice about the () operator for matrices:
+//			-> http://parashift.com/c++-faq-lite/
 //
 //		You may find more information on the FET documentation web page, https://lalescu.ro/liviu/fet/doc/
 
@@ -93,6 +95,8 @@ public:
 template <typename T> Matrix3D<T>::Matrix3D()
 {
 	d1=d2=d3=-1;
+	a=NULL;
+	content=NULL;
 }
 
 template <typename T> Matrix3D<T>::~Matrix3D()
@@ -107,7 +111,7 @@ template <typename T> void Matrix3D<T>::clear()
 		
 		for(int i=0; i<d1; i++)
 			delete[] a[i];
-		delete[]a;
+		delete[] a;
 		
 		delete[] content;
 	}
@@ -153,6 +157,8 @@ template <typename T> inline T& Matrix3D<T>::operator()(int i, int j, int k)
 template <typename T> Matrix2D<T>::Matrix2D()
 {
 	d1=d2=-1;
+	a=NULL;
+	content=NULL;
 }
 
 template <typename T> Matrix2D<T>::~Matrix2D()
@@ -206,6 +212,7 @@ template <typename T> inline T& Matrix2D<T>::operator()(int i, int j)
 template <typename T> Matrix1D<T>::Matrix1D()
 {
 	d1=-1;
+	a=NULL;
 }
 
 template <typename T> Matrix1D<T>::~Matrix1D()
