@@ -32,6 +32,8 @@ File solution.h
 
 class Rules;
 
+class FakeString;
+
 /**
 This class represents a solution (time and space allocation for the activities).
 */
@@ -63,6 +65,8 @@ public:
 	int times[MAX_ACTIVITIES];
 	
 	int rooms[MAX_ACTIVITIES];
+	
+	Matrix1D<QList<int> > realRoomsList; //for virtual rooms
 
 	/**
 	Fitness; it is calculated only at the initialization or
@@ -95,7 +99,7 @@ public:
 	If conflictsString is not null, then this function will
 	append at this string an explanation of the conflicts.
 	*/
-	double fitness(Rules& r, QString* conflictsString=NULL);
+	double fitness(Rules& r, FakeString* conflictsString=NULL);
 
 	void getTeachersTimetable(Rules& r, Matrix3D<int>& a, Matrix3D<QList<int> >& b);
 	//return value is the number of conflicts, which must be 0
@@ -103,7 +107,7 @@ public:
 	void getSubgroupsTimetable(Rules& r, Matrix3D<int>& a);
 	//return value is the number of conflicts, which must be 0
 
-	void getRoomsTimetable(Rules& r, Matrix3D<int>& a);
+	void getRoomsTimetable(Rules& r, Matrix3D<int>& a, Matrix3D<QList<int> >& va);
 	//return value is the number of conflicts, which must be 0
 
 	int getSubgroupsMatrix(Rules& r, Matrix3D<int>& a);
