@@ -37,7 +37,7 @@ int STUDENTS_COMBO_BOXES_STYLE=STUDENTS_COMBO_BOXES_STYLE_SIMPLE;
 /**
 FET version
 */
-const QString FET_VERSION="5.44.3";
+const QString FET_VERSION="5.48.1";
 
 /**
 FET language
@@ -227,6 +227,13 @@ double customFETStrToDouble(const QString& str, bool* ok)
 }
 ///////end tricks
 
+bool BEEP_AT_END_OF_GENERATION=true;
+bool ENABLE_COMMAND_AT_END_OF_GENERATION=true;
+QString commandAtEndOfGeneration=QString("");
+//bool DETACHED_NOTIFICATION=false;
+//int terminateCommandAfterSeconds=0;
+//int killCommandAfterSeconds=0;
+
 /*
 int XX;
 int YY;
@@ -427,11 +434,11 @@ void MRG32k3a::initializeMRG32k3a()
 	//cout<<"si=="<<si<<endl;
 	assert(si>=0);
 	_s10=si%m1;
-	if(_s10==0) //just in case :-)  . Also, it could be allowed to be 0, but we don't have guarantees that not all seeds in component 1 are 0.
+	if(_s10==0) //just in case :-)  . It could even be allowed to be 0, but then we wouldn't have a certain guarantee that not all seeds in component 1 are 0.
 		_s10=1;
 
 	_s20=si%m2;
-	if(_s20==0) //just in case :-)  . Also, it could be allowed to be 0, but we don't have guarantees that not all seeds in component 2 are 0.
+	if(_s20==0) //just in case :-)  . It could even be allowed to be 0, but then we wouldn't have a certain guarantee that not all seeds in component 2 are 0.
 		_s20=1;
 
 	/*_s10 = 1 + tt%(m1-1);
