@@ -123,6 +123,8 @@ extern bool SHOW_WARNING_FOR_SUBGROUPS_WITH_THE_SAME_ACTIVITIES;
 
 extern bool SHOW_WARNING_FOR_ACTIVITIES_FIXED_SPACE_VIRTUAL_REAL_ROOMS_BUT_NOT_FIXED_TIME;
 
+extern bool SHOW_WARNING_FOR_MAX_HOURS_DAILY_WITH_UNDER_100_WEIGHT;
+
 extern bool ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS;
 extern bool SHOW_WARNING_FOR_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS;
 
@@ -184,7 +186,7 @@ DEPRECATED COMMENT BELOW
 IMPORTANT: max hours per day * max days per week = max hours per week must be qint16 (max 32767),
 because each time is qint16 and unallocated time is qint16
 */
-const int MAX_HOURS_PER_DAY=60;
+const int MAX_HOURS_PER_DAY=72;
 
 /**
 The maximum number of working days per week.
@@ -328,8 +330,9 @@ const int STUDENTS_COMBO_BOXES_STYLE_CATEGORIZED=2;
 extern int STUDENTS_COMBO_BOXES_STYLE;
 
 ///////tricks to save work to reconvert old code
-const int CUSTOM_DOUBLE_PRECISION=6; //number of digits after the decimal dot for the weights
+const int CUSTOM_DOUBLE_PRECISION=6; //the maximum number of significant digits after the decimal dot for the weights
 const int MULTIPLICANT_DOUBLE_PRECISION=100000000; //10^(2+CUSTOM_DOUBLE_PRECISION)
+const int HALF_MULTIPLICANT_DOUBLE_PRECISION=MULTIPLICANT_DOUBLE_PRECISION/2;
 
 void weight_sscanf(const QString& str, const char* fmt, double* result);
 
@@ -357,6 +360,13 @@ inline bool operator<(const LocaleString& lhs, const LocaleString& rhs)
 }
 /////////////////////////////////////////////////////
 
+extern bool BEEP_AT_END_OF_GENERATION;
+extern bool ENABLE_COMMAND_AT_END_OF_GENERATION;
+extern QString commandAtEndOfGeneration;
+//extern bool DETACHED_NOTIFICATION;
+//extern int terminateCommandAfterSeconds;
+//extern int killCommandAfterSeconds;
+
 //Old RNG below
 //for random Knuth - from Knuth TAOCP Vol. 2 Seminumerical Algorithms section 3.6
 //these numbers are really important - please do not change them, NEVER!!!
