@@ -63,19 +63,16 @@ ActivitiesForm::ActivitiesForm(QWidget* parent, const QString& teacherName, cons
 	//restore splitter state
 	if(settings.contains(this->metaObject()->className()+QString("/splitter-state")))
 		splitter->restoreState(settings.value(this->metaObject()->className()+QString("/splitter-state")).toByteArray());
-	recursiveCheckBox->setChecked(settings.value(this->metaObject()->className()+QString("/show-related-check-box-state"), "false").toBool());
+	showRelatedCheckBox->setChecked(settings.value(this->metaObject()->className()+QString("/show-related-check-box-state"), "false").toBool());
 	
 	connect(activitiesListWidget, SIGNAL(currentRowChanged(int)), this, SLOT(activityChanged()));
 	connect(addActivityPushButton, SIGNAL(clicked()), this, SLOT(addActivity()));
 	connect(removeActivityPushButton, SIGNAL(clicked()), this, SLOT(removeActivity()));
 	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
-	connect(teachersComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(studentsComboBox, SIGNAL(activated(QString)), this, SLOT(studentsFilterChanged()));
-	connect(subjectsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
+
 	connect(modifyActivityPushButton, SIGNAL(clicked()), this, SLOT(modifyActivity()));
-	connect(activityTagsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
 	connect(activitiesListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(modifyActivity()));
-	connect(recursiveCheckBox, SIGNAL(toggled(bool)), this, SLOT(studentsFilterChanged()));
+	connect(showRelatedCheckBox, SIGNAL(toggled(bool)), this, SLOT(studentsFilterChanged()));
 	connect(helpPushButton, SIGNAL(clicked()), this, SLOT(help()));
 	connect(commentsPushButton, SIGNAL(clicked()), this, SLOT(activityComments()));
 
@@ -119,30 +116,6 @@ ActivitiesForm::ActivitiesForm(QWidget* parent, const QString& teacherName, cons
 	activityTagsComboBox->setCurrentIndex(ciat);
 
 	int cist=populateStudentsComboBox(studentsComboBox, studentsSetName, true);
-	/*studentsComboBox->addItem("");
-	int cist=0;
-	int currentID=0;
-	for(int i=0; i<gt.rules.yearsList.size(); i++){
-		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->addItem(sty->name);
-		currentID++;
-		if(sty->name==studentsSetName)
-			cist=currentID;
-		for(int j=0; j<sty->groupsList.size(); j++){
-			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->addItem(stg->name);
-			currentID++;
-			if(stg->name==studentsSetName)
-				cist=currentID;
-			if(SHOW_SUBGROUPS_IN_COMBO_BOXES) for(int k=0; k<stg->subgroupsList.size(); k++){
-				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->addItem(sts->name);
-				currentID++;
-				if(sts->name==studentsSetName)
-					cist=currentID;
-			}
-		}
-	}*/
 	if(studentsSetName==""){
 		assert(cist==0);
 		studentsComboBox->setCurrentIndex(0);
@@ -172,27 +145,10 @@ ActivitiesForm::ActivitiesForm(QWidget* parent, const QString& teacherName, cons
 		}
 	}
 
-	/*studentsComboBox->setCurrentIndex(cist);
-	
-	if(studentsSetName!=""){
-		if(cist==0){
-			showWarningForInvisibleSubgroupActivity(parent, studentsSetName);
-
-			showedStudents.clear();
-			showedStudents.insert("");
-	
-			filterChanged();
-		}
-		else{
-			this->studentsFilterChanged();
-		}
-	}
-	else{
-		showedStudents.clear();
-		showedStudents.insert("");
-	
-		filterChanged();
-	}*/
+	connect(teachersComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(studentsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(studentsFilterChanged()));
+	connect(subjectsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(activityTagsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
 }
 
 ActivitiesForm::~ActivitiesForm()
@@ -202,7 +158,7 @@ ActivitiesForm::~ActivitiesForm()
 	QSettings settings(COMPANY, PROGRAM);
 	settings.setValue(this->metaObject()->className()+QString("/splitter-state"), splitter->saveState());
 
-	settings.setValue(this->metaObject()->className()+QString("/show-related-check-box-state"), recursiveCheckBox->isChecked());
+	settings.setValue(this->metaObject()->className()+QString("/show-related-check-box-state"), showRelatedCheckBox->isChecked());
 }
 
 bool ActivitiesForm::filterOk(Activity* act)
@@ -210,13 +166,13 @@ bool ActivitiesForm::filterOk(Activity* act)
 	QString tn=teachersComboBox->currentText();
 	QString stn=studentsComboBox->currentText();
 	QString sbn=subjectsComboBox->currentText();
-	QString sbtn=activityTagsComboBox->currentText();
+	QString atn=activityTagsComboBox->currentText();
 	int ok=true;
 
 	//teacher
 	if(tn!=""){
 		bool ok2=false;
-		for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+		for(QStringList::const_iterator it=act->teachersNames.constBegin(); it!=act->teachersNames.constEnd(); it++)
 			if(*it == tn){
 				ok2=true;
 				break;
@@ -230,13 +186,13 @@ bool ActivitiesForm::filterOk(Activity* act)
 		ok=false;
 		
 	//activity tag
-	if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
+	if(atn!="" && !act->activityTagsNames.contains(atn))
 		ok=false;
 		
 	//students
 	if(stn!=""){
 		bool ok2=false;
-		for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+		for(QStringList::const_iterator it=act->studentsNames.constBegin(); it!=act->studentsNames.constEnd(); it++)
 			//if(*it == stn){
 			if(showedStudents.contains(*it)){
 				ok2=true;
@@ -255,11 +211,11 @@ bool ActivitiesForm::filterOk(Activity* act)
 
 void ActivitiesForm::studentsFilterChanged()
 {
-	bool showContained=recursiveCheckBox->isChecked();
+	bool showRelated=showRelatedCheckBox->isChecked();
 	
 	showedStudents.clear();
 	
-	if(!showContained){
+	if(!showRelated){
 		showedStudents.insert(studentsComboBox->currentText());
 	}
 	else{
@@ -348,9 +304,9 @@ void ActivitiesForm::filterChanged()
 	
 	assert(nsubacts-ninact>=0);
 	assert(nh-ninacth>=0);
-	activeTextLabel->setText(tr("No: %1 / %2", "No means number, %1 is the number of active activities, %2 is the number of total activities."
+	activeTextLabel->setText(tr("No: %1 / %2", "No means number, %1 is the number of active activities, %2 is the total number of activities."
 		" Please leave spaces between fields, so that they are better visible").arg(nsubacts-ninact).arg(nsubacts));
-	totalTextLabel->setText(tr("Dur: %1 / %2", "Dur means duration, %1 is the duration of active activities, %2 is the duration of total activities."
+	totalTextLabel->setText(tr("Dur: %1 / %2", "Dur means duration, %1 is the duration of active activities, %2 is the total duration of activities."
 		" Please leave spaces between fields, so that they are better visible").arg(nh-ninacth).arg(nh));
 	
 	if(activitiesListWidget->count()>0)
