@@ -50,7 +50,11 @@ ActivitiesRoomsStatisticsForm::ActivitiesRoomsStatisticsForm(QWidget* parent): Q
 		if(!act->active)
 			continue;
 	
+#if QT_VERSION >= QT_VERSION_CHECK(5,14,0)
+		QSet<QString> currentActivityTagsSet(act->activityTagsNames.begin(), act->activityTagsNames.end());
+#else
 		QSet<QString> currentActivityTagsSet=act->activityTagsNames.toSet();
+#endif
 	
 		for(SpaceConstraint* genericConstraint : qAsConst(gt.rules.spaceConstraintsList)){
 			if(!genericConstraint->active)
