@@ -37,8 +37,6 @@ AddConstraintStudentsMaxGapsPerDayForm::AddConstraintStudentsMaxGapsPerDayForm(Q
 	maxGapsSpinBox->setMinimum(0);
 	maxGapsSpinBox->setMaximum(gt.rules.nHoursPerDay);
 	maxGapsSpinBox->setValue(1);
-	
-	constraintChanged();
 }
 
 AddConstraintStudentsMaxGapsPerDayForm::~AddConstraintStudentsMaxGapsPerDayForm()
@@ -46,10 +44,6 @@ AddConstraintStudentsMaxGapsPerDayForm::~AddConstraintStudentsMaxGapsPerDayForm(
 	saveFETDialogGeometry(this);
 }
 
-void AddConstraintStudentsMaxGapsPerDayForm::constraintChanged()
-{
-}
-
 void AddConstraintStudentsMaxGapsPerDayForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
