@@ -37,8 +37,6 @@ AddConstraintStudentsMaxSpanPerDayForm::AddConstraintStudentsMaxSpanPerDayForm(Q
 	maxSpanSpinBox->setMinimum(1);
 	maxSpanSpinBox->setMaximum(gt.rules.nHoursPerDay);
 	maxSpanSpinBox->setValue(gt.rules.nHoursPerDay);
-	
-	constraintChanged();
 }
 
 AddConstraintStudentsMaxSpanPerDayForm::~AddConstraintStudentsMaxSpanPerDayForm()
@@ -46,10 +44,6 @@ AddConstraintStudentsMaxSpanPerDayForm::~AddConstraintStudentsMaxSpanPerDayForm(
 	saveFETDialogGeometry(this);
 }
 
-void AddConstraintStudentsMaxSpanPerDayForm::constraintChanged()
-{
-}
-
 void AddConstraintStudentsMaxSpanPerDayForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
