@@ -37,8 +37,6 @@ AddConstraintStudentsMinGapsBetweenBuildingChangesForm::AddConstraintStudentsMin
 	minGapsSpinBox->setMinimum(1);
 	minGapsSpinBox->setMaximum(gt.rules.nHoursPerDay);
 	minGapsSpinBox->setValue(1);
-	
-	constraintChanged();
 }
 
 AddConstraintStudentsMinGapsBetweenBuildingChangesForm::~AddConstraintStudentsMinGapsBetweenBuildingChangesForm()
@@ -46,10 +44,6 @@ AddConstraintStudentsMinGapsBetweenBuildingChangesForm::~AddConstraintStudentsMi
 	saveFETDialogGeometry(this);
 }
 
-void AddConstraintStudentsMinGapsBetweenBuildingChangesForm::constraintChanged()
-{
-}
-
 void AddConstraintStudentsMinGapsBetweenBuildingChangesForm::addCurrentConstraint()
 {
 	SpaceConstraint *ctr=NULL;
