@@ -39,8 +39,6 @@ AddConstraintStudentsMinRestingHoursForm::AddConstraintStudentsMinRestingHoursFo
 	minRestingHoursSpinBox->setMinimum(1);
 	minRestingHoursSpinBox->setMaximum(gt.rules.nHoursPerDay);
 	minRestingHoursSpinBox->setValue(1);
-	
-	constraintChanged();
 }
 
 AddConstraintStudentsMinRestingHoursForm::~AddConstraintStudentsMinRestingHoursForm()
@@ -48,10 +46,6 @@ AddConstraintStudentsMinRestingHoursForm::~AddConstraintStudentsMinRestingHoursF
 	saveFETDialogGeometry(this);
 }
 
-void AddConstraintStudentsMinRestingHoursForm::constraintChanged()
-{
-}
-
 void AddConstraintStudentsMinRestingHoursForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
