@@ -56,21 +56,6 @@ AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::~AddConstraintStudentsSetInt
 void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateStudentsComboBox()
 {
 	populateStudentsComboBox(studentsComboBox);
-	/*studentsComboBox->clear();
-	for(int i=0; i<gt.rules.yearsList.size(); i++){
-		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->addItem(sty->name);
-		for(int j=0; j<sty->groupsList.size(); j++){
-			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->addItem(stg->name);
-			if(SHOW_SUBGROUPS_IN_COMBO_BOXES) for(int k=0; k<stg->subgroupsList.size(); k++){
-				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->addItem(sts->name);
-			}
-		}
-	}*/
-
-	constraintChanged();
 }
 
 void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateMaxDaysSpinBox(){
@@ -85,8 +70,6 @@ void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateStartHoursComboBo
 	for(int i=0; i<gt.rules.nHoursPerDay; i++)
 		startHourComboBox->addItem(gt.rules.hoursOfTheDay[i]);
 	startHourComboBox->setCurrentIndex(gt.rules.nHoursPerDay-1);
-	
-	constraintChanged();
 }
 
 void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateEndHoursComboBox()
@@ -96,12 +79,6 @@ void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateEndHoursComboBox(
 		endHourComboBox->addItem(gt.rules.hoursOfTheDay[i]);
 	endHourComboBox->addItem(tr("End of day"));
 	endHourComboBox->setCurrentIndex(gt.rules.nHoursPerDay);
-	
-	constraintChanged();
-}
-
-void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::constraintChanged()
-{
 }
 
 void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::addCurrentConstraint()
