@@ -49,33 +49,14 @@ AddConstraintStudentsSetMaxDaysPerWeekForm::~AddConstraintStudentsSetMaxDaysPerW
 void AddConstraintStudentsSetMaxDaysPerWeekForm::updateStudentsComboBox()
 {
 	populateStudentsComboBox(studentsComboBox);
-	/*studentsComboBox->clear();
-	for(int i=0; i<gt.rules.yearsList.size(); i++){
-		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->addItem(sty->name);
-		for(int j=0; j<sty->groupsList.size(); j++){
-			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->addItem(stg->name);
-			if(SHOW_SUBGROUPS_IN_COMBO_BOXES) for(int k=0; k<stg->subgroupsList.size(); k++){
-				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->addItem(sts->name);
-			}
-		}
-	}*/
-
-	constraintChanged();
 }
 
 void AddConstraintStudentsSetMaxDaysPerWeekForm::updateMaxDaysSpinBox(){
-	maxDaysSpinBox->setMinimum(0);
+	maxDaysSpinBox->setMinimum(1);
 	maxDaysSpinBox->setMaximum(gt.rules.nDaysPerWeek);
 	maxDaysSpinBox->setValue(gt.rules.nDaysPerWeek);
 }
 
-void AddConstraintStudentsSetMaxDaysPerWeekForm::constraintChanged()
-{
-}
-
 void AddConstraintStudentsSetMaxDaysPerWeekForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
