@@ -42,8 +42,6 @@ AddConstraintStudentsSetMaxGapsPerDayForm::AddConstraintStudentsSetMaxGapsPerDay
 	maxGapsSpinBox->setValue(1);
 
 	updateStudentsSetComboBox();
-	
-	constraintChanged();
 }
 
 AddConstraintStudentsSetMaxGapsPerDayForm::~AddConstraintStudentsSetMaxGapsPerDayForm()
@@ -54,25 +52,6 @@ AddConstraintStudentsSetMaxGapsPerDayForm::~AddConstraintStudentsSetMaxGapsPerDa
 void AddConstraintStudentsSetMaxGapsPerDayForm::updateStudentsSetComboBox()
 {
 	populateStudentsComboBox(studentsComboBox);
-	/*studentsComboBox->clear();
-	for(int i=0; i<gt.rules.yearsList.size(); i++){
-		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->addItem(sty->name);
-		for(int j=0; j<sty->groupsList.size(); j++){
-			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->addItem(stg->name);
-			if(SHOW_SUBGROUPS_IN_COMBO_BOXES) for(int k=0; k<stg->subgroupsList.size(); k++){
-				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->addItem(sts->name);
-			}
-		}
-	}*/
-
-	constraintChanged();
-}
-
-void AddConstraintStudentsSetMaxGapsPerDayForm::constraintChanged()
-{
 }
 
 void AddConstraintStudentsSetMaxGapsPerDayForm::addCurrentConstraint()
