@@ -52,8 +52,6 @@ void AddConstraintTeacherMaxDaysPerWeekForm::updateTeachersComboBox(){
 		Teacher* tch=gt.rules.teachersList[i];
 		teachersComboBox->addItem(tch->name);
 	}
-
-	constraintChanged();
 }
 
 void AddConstraintTeacherMaxDaysPerWeekForm::updateMaxDaysSpinBox(){
@@ -62,10 +60,6 @@ void AddConstraintTeacherMaxDaysPerWeekForm::updateMaxDaysSpinBox(){
 	maxDaysSpinBox->setValue(gt.rules.nDaysPerWeek);
 }
 
-void AddConstraintTeacherMaxDaysPerWeekForm::constraintChanged()
-{
-}
-
 void AddConstraintTeacherMaxDaysPerWeekForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
