@@ -46,8 +46,6 @@ AddConstraintTeacherMaxGapsPerWeekForm::AddConstraintTeacherMaxGapsPerWeekForm(Q
 		Teacher* tch=gt.rules.teachersList[i];
 		teachersComboBox->addItem(tch->name);
 	}
-
-	constraintChanged();
 }
 
 AddConstraintTeacherMaxGapsPerWeekForm::~AddConstraintTeacherMaxGapsPerWeekForm()
@@ -55,10 +53,6 @@ AddConstraintTeacherMaxGapsPerWeekForm::~AddConstraintTeacherMaxGapsPerWeekForm(
 	saveFETDialogGeometry(this);
 }
 
-void AddConstraintTeacherMaxGapsPerWeekForm::constraintChanged()
-{
-}
-
 void AddConstraintTeacherMaxGapsPerWeekForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
