@@ -44,8 +44,6 @@ AddConstraintTeacherMaxHoursContinuouslyForm::AddConstraintTeacherMaxHoursContin
 		Teacher* tch=gt.rules.teachersList[i];
 		teachersComboBox->addItem(tch->name);
 	}
-
-	constraintChanged();
 }
 
 AddConstraintTeacherMaxHoursContinuouslyForm::~AddConstraintTeacherMaxHoursContinuouslyForm()
@@ -59,10 +57,6 @@ void AddConstraintTeacherMaxHoursContinuouslyForm::updateMaxHoursSpinBox(){
 	maxHoursSpinBox->setValue(gt.rules.nHoursPerDay);
 }
 
-void AddConstraintTeacherMaxHoursContinuouslyForm::constraintChanged()
-{
-}
-
 void AddConstraintTeacherMaxHoursContinuouslyForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
