@@ -48,8 +48,6 @@ AddConstraintTeacherMaxSpanPerDayForm::AddConstraintTeacherMaxSpanPerDayForm(QWi
 	}
 	
 	exceptionCheckBox->setChecked(false);
-
-	constraintChanged();
 }
 
 AddConstraintTeacherMaxSpanPerDayForm::~AddConstraintTeacherMaxSpanPerDayForm()
@@ -57,10 +55,6 @@ AddConstraintTeacherMaxSpanPerDayForm::~AddConstraintTeacherMaxSpanPerDayForm()
 	saveFETDialogGeometry(this);
 }
 
-void AddConstraintTeacherMaxSpanPerDayForm::constraintChanged()
-{
-}
-
 void AddConstraintTeacherMaxSpanPerDayForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
