@@ -44,8 +44,6 @@ AddConstraintTeacherMinHoursDailyForm::AddConstraintTeacherMinHoursDailyForm(QWi
 		Teacher* tch=gt.rules.teachersList[i];
 		teachersComboBox->addItem(tch->name);
 	}
-
-	constraintChanged();
 }
 
 AddConstraintTeacherMinHoursDailyForm::~AddConstraintTeacherMinHoursDailyForm()
@@ -59,10 +57,6 @@ void AddConstraintTeacherMinHoursDailyForm::updateMinHoursSpinBox(){
 	minHoursSpinBox->setValue(2);
 }
 
-void AddConstraintTeacherMinHoursDailyForm::constraintChanged()
-{
-}
-
 void AddConstraintTeacherMinHoursDailyForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
