@@ -48,8 +48,6 @@ AddConstraintTeacherMinRestingHoursForm::AddConstraintTeacherMinRestingHoursForm
 		Teacher* tch=gt.rules.teachersList[i];
 		teachersComboBox->addItem(tch->name);
 	}
-
-	constraintChanged();
 }
 
 AddConstraintTeacherMinRestingHoursForm::~AddConstraintTeacherMinRestingHoursForm()
@@ -57,10 +55,6 @@ AddConstraintTeacherMinRestingHoursForm::~AddConstraintTeacherMinRestingHoursFor
 	saveFETDialogGeometry(this);
 }
 
-void AddConstraintTeacherMinRestingHoursForm::constraintChanged()
-{
-}
-
 void AddConstraintTeacherMinRestingHoursForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
