@@ -61,8 +61,6 @@ void AddConstraintTeachersIntervalMaxDaysPerWeekForm::updateStartHoursComboBox()
 	for(int i=0; i<gt.rules.nHoursPerDay; i++)
 		startHourComboBox->addItem(gt.rules.hoursOfTheDay[i]);
 	startHourComboBox->setCurrentIndex(gt.rules.nHoursPerDay-1);
-	
-	constraintChanged();
 }
 
 void AddConstraintTeachersIntervalMaxDaysPerWeekForm::updateEndHoursComboBox()
@@ -72,12 +70,6 @@ void AddConstraintTeachersIntervalMaxDaysPerWeekForm::updateEndHoursComboBox()
 		endHourComboBox->addItem(gt.rules.hoursOfTheDay[i]);
 	endHourComboBox->addItem(tr("End of day"));
 	endHourComboBox->setCurrentIndex(gt.rules.nHoursPerDay);
-	
-	constraintChanged();
-}
-
-void AddConstraintTeachersIntervalMaxDaysPerWeekForm::constraintChanged()
-{
 }
 
 void AddConstraintTeachersIntervalMaxDaysPerWeekForm::addCurrentConstraint()
