@@ -37,8 +37,6 @@ AddConstraintTeachersMaxGapsPerDayForm::AddConstraintTeachersMaxGapsPerDayForm(Q
 	maxGapsSpinBox->setMinimum(0);
 	maxGapsSpinBox->setMaximum(gt.rules.nHoursPerDay);
 	maxGapsSpinBox->setValue(1);
-	
-	constraintChanged();
 }
 
 AddConstraintTeachersMaxGapsPerDayForm::~AddConstraintTeachersMaxGapsPerDayForm()
@@ -46,10 +44,6 @@ AddConstraintTeachersMaxGapsPerDayForm::~AddConstraintTeachersMaxGapsPerDayForm(
 	saveFETDialogGeometry(this);
 }
 
-void AddConstraintTeachersMaxGapsPerDayForm::constraintChanged()
-{
-}
-
 void AddConstraintTeachersMaxGapsPerDayForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
