@@ -35,8 +35,6 @@ AddConstraintTeachersMaxHoursContinuouslyForm::AddConstraintTeachersMaxHoursCont
 	restoreFETDialogGeometry(this);
 	
 	updateMaxHoursSpinBox();
-	
-	constraintChanged();
 }
 
 AddConstraintTeachersMaxHoursContinuouslyForm::~AddConstraintTeachersMaxHoursContinuouslyForm()
@@ -50,10 +48,6 @@ void AddConstraintTeachersMaxHoursContinuouslyForm::updateMaxHoursSpinBox(){
 	maxHoursSpinBox->setValue(gt.rules.nHoursPerDay);
 }
 
-void AddConstraintTeachersMaxHoursContinuouslyForm::constraintChanged()
-{
-}
-
 void AddConstraintTeachersMaxHoursContinuouslyForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
