@@ -39,8 +39,6 @@ AddConstraintTeachersMaxSpanPerDayForm::AddConstraintTeachersMaxSpanPerDayForm(Q
 	maxSpanSpinBox->setValue(gt.rules.nHoursPerDay);
 
 	exceptionCheckBox->setChecked(false);
-	
-	constraintChanged();
 }
 
 AddConstraintTeachersMaxSpanPerDayForm::~AddConstraintTeachersMaxSpanPerDayForm()
@@ -48,10 +46,6 @@ AddConstraintTeachersMaxSpanPerDayForm::~AddConstraintTeachersMaxSpanPerDayForm(
 	saveFETDialogGeometry(this);
 }
 
-void AddConstraintTeachersMaxSpanPerDayForm::constraintChanged()
-{
-}
-
 void AddConstraintTeachersMaxSpanPerDayForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
