@@ -37,8 +37,6 @@ AddConstraintTeachersMinGapsBetweenBuildingChangesForm::AddConstraintTeachersMin
 	minGapsSpinBox->setMinimum(1);
 	minGapsSpinBox->setMaximum(gt.rules.nHoursPerDay);
 	minGapsSpinBox->setValue(1);
-
-	constraintChanged();
 }
 
 AddConstraintTeachersMinGapsBetweenBuildingChangesForm::~AddConstraintTeachersMinGapsBetweenBuildingChangesForm()
@@ -46,11 +44,6 @@ AddConstraintTeachersMinGapsBetweenBuildingChangesForm::~AddConstraintTeachersMi
 	saveFETDialogGeometry(this);
 }
 
-
-void AddConstraintTeachersMinGapsBetweenBuildingChangesForm::constraintChanged()
-{
-}
-
 void AddConstraintTeachersMinGapsBetweenBuildingChangesForm::addCurrentConstraint()
 {
 	SpaceConstraint *ctr=NULL;
