@@ -35,8 +35,6 @@ AddConstraintTeachersMinHoursDailyForm::AddConstraintTeachersMinHoursDailyForm(Q
 	restoreFETDialogGeometry(this);
 	
 	updateMinHoursSpinBox();
-	
-	constraintChanged();
 }
 
 AddConstraintTeachersMinHoursDailyForm::~AddConstraintTeachersMinHoursDailyForm()
@@ -50,10 +48,6 @@ void AddConstraintTeachersMinHoursDailyForm::updateMinHoursSpinBox(){
 	minHoursSpinBox->setValue(2);
 }
 
-void AddConstraintTeachersMinHoursDailyForm::constraintChanged()
-{
-}
-
 void AddConstraintTeachersMinHoursDailyForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
