@@ -30,10 +30,6 @@ AddConstraintTwoActivitiesGroupedForm::AddConstraintTwoActivitiesGroupedForm(QWi
 
 	connect(addConstraintPushButton, SIGNAL(clicked()), this, SLOT(addCurrentConstraint()));
 	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
-	connect(teachersComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(studentsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(subjectsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(activityTagsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
 
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
@@ -77,22 +73,14 @@ AddConstraintTwoActivitiesGroupedForm::AddConstraintTwoActivitiesGroupedForm(QWi
 	activityTagsComboBox->setCurrentIndex(0);
 
 	populateStudentsComboBox(studentsComboBox, QString(""), true);
-	/*studentsComboBox->addItem("");
-	for(int i=0; i<gt.rules.yearsList.size(); i++){
-		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->addItem(sty->name);
-		for(int j=0; j<sty->groupsList.size(); j++){
-			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->addItem(stg->name);
-			if(SHOW_SUBGROUPS_IN_COMBO_BOXES) for(int k=0; k<stg->subgroupsList.size(); k++){
-				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->addItem(sts->name);
-			}
-		}
-	}*/
 	studentsComboBox->setCurrentIndex(0);
 
-	updateActivitiesComboBox();
+	filterChanged();
+
+	connect(teachersComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(studentsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(subjectsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(activityTagsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
 }
 
 AddConstraintTwoActivitiesGroupedForm::~AddConstraintTwoActivitiesGroupedForm()
@@ -105,13 +93,13 @@ bool AddConstraintTwoActivitiesGroupedForm::filterOk(Activity* act)
 	QString tn=teachersComboBox->currentText();
 	QString stn=studentsComboBox->currentText();
 	QString sbn=subjectsComboBox->currentText();
-	QString sbtn=activityTagsComboBox->currentText();
+	QString atn=activityTagsComboBox->currentText();
 	int ok=true;
 
 	//teacher
 	if(tn!=""){
 		bool ok2=false;
-		for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+		for(QStringList::const_iterator it=act->teachersNames.constBegin(); it!=act->teachersNames.constEnd(); it++)
 			if(*it == tn){
 				ok2=true;
 				break;
@@ -125,13 +113,13 @@ bool AddConstraintTwoActivitiesGroupedForm::filterOk(Activity* act)
 		ok=false;
 		
 	//activity tag
-	if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
+	if(atn!="" && !act->activityTagsNames.contains(atn))
 		ok=false;
 		
 	//students
 	if(stn!=""){
 		bool ok2=false;
-		for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+		for(QStringList::const_iterator it=act->studentsNames.constBegin(); it!=act->studentsNames.constEnd(); it++)
 			if(*it == stn){
 				ok2=true;
 				break;
@@ -143,7 +131,7 @@ bool AddConstraintTwoActivitiesGroupedForm::filterOk(Activity* act)
 	return ok;
 }
 
-void AddConstraintTwoActivitiesGroupedForm::updateActivitiesComboBox(){
+void AddConstraintTwoActivitiesGroupedForm::filterChanged(){
 	firstActivitiesComboBox->clear();
 	firstActivitiesList.clear();
 
@@ -161,17 +149,6 @@ void AddConstraintTwoActivitiesGroupedForm::updateActivitiesComboBox(){
 			this->secondActivitiesList.append(act->id);
 		}
 	}
-
-	constraintChanged();
-}
-
-void AddConstraintTwoActivitiesGroupedForm::filterChanged()
-{
-	this->updateActivitiesComboBox();
-}
-
-void AddConstraintTwoActivitiesGroupedForm::constraintChanged()
-{
 }
 
 void AddConstraintTwoActivitiesGroupedForm::addCurrentConstraint()
