@@ -43,10 +43,7 @@ ConstraintActivitiesSameStartingTimeForm::ConstraintActivitiesSameStartingTimeFo
 	connect(constraintsListWidget, SIGNAL(currentRowChanged(int)), this, SLOT(constraintChanged(int)));
 	connect(modifyConstraintPushButton, SIGNAL(clicked()), this, SLOT(modifyConstraint()));
 	connect(constraintsListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(modifyConstraint()));
-	connect(teachersComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(studentsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(subjectsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(activityTagsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
+
 	connect(helpPushButton, SIGNAL(clicked()), this, SLOT(help()));
 
 	centerWidgetOnScreen(this);
@@ -84,23 +81,15 @@ ConstraintActivitiesSameStartingTimeForm::ConstraintActivitiesSameStartingTimeFo
 	activityTagsComboBox->setCurrentIndex(0);
 
 	populateStudentsComboBox(studentsComboBox, QString(""), true);
-	/*studentsComboBox->addItem("");
-	for(int i=0; i<gt.rules.yearsList.size(); i++){
-		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->addItem(sty->name);
-		for(int j=0; j<sty->groupsList.size(); j++){
-			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->addItem(stg->name);
-			if(SHOW_SUBGROUPS_IN_COMBO_BOXES) for(int k=0; k<stg->subgroupsList.size(); k++){
-				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->addItem(sts->name);
-			}
-		}
-	}*/
 	studentsComboBox->setCurrentIndex(0);
 ///////////////
 
 	this->filterChanged();
+
+	connect(teachersComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(studentsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(subjectsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(activityTagsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
 }
 
 ConstraintActivitiesSameStartingTimeForm::~ConstraintActivitiesSameStartingTimeForm()
@@ -108,28 +97,6 @@ ConstraintActivitiesSameStartingTimeForm::~ConstraintActivitiesSameStartingTimeF
 	saveFETDialogGeometry(this);
 }
 
-void ConstraintActivitiesSameStartingTimeForm::refreshConstraintsListWidget()
-{
-	this->visibleConstraintsList.clear();
-	constraintsListWidget->clear();
-	for(int i=0; i<gt.rules.timeConstraintsList.size(); i++){
-		TimeConstraint* ctr=gt.rules.timeConstraintsList[i];
-		if(filterOk(ctr)){
-			QString s;
-			s=ctr->getDescription(gt.rules);
-			visibleConstraintsList.append(ctr);
-			constraintsListWidget->addItem(s);
-		}
-	}
-
-	if(constraintsListWidget->count()>0){
-		constraintsListWidget->setCurrentRow(0);
-		constraintChanged(constraintsListWidget->currentRow());
-	}
-	else
-		constraintChanged(-1);
-}
-
 bool ConstraintActivitiesSameStartingTimeForm::filterOk(TimeConstraint* ctr)
 {
 	if(ctr->type!=CONSTRAINT_ACTIVITIES_SAME_STARTING_TIME)
@@ -139,10 +106,10 @@ bool ConstraintActivitiesSameStartingTimeForm::filterOk(TimeConstraint* ctr)
 	
 	QString tn=teachersComboBox->currentText();
 	QString sbn=subjectsComboBox->currentText();
-	QString sbtn=activityTagsComboBox->currentText();
+	QString atn=activityTagsComboBox->currentText();
 	QString stn=studentsComboBox->currentText();
 	
-	if(tn=="" && sbn=="" && sbtn=="" && stn=="")
+	if(tn=="" && sbn=="" && atn=="" && stn=="")
 		return true;
 	
 	bool foundTeacher=false, foundStudents=false, foundSubject=false, foundActivityTag=false;
@@ -151,16 +118,17 @@ bool ConstraintActivitiesSameStartingTimeForm::filterOk(TimeConstraint* ctr)
 		//bool found=true;
 	
 		int id=c->activitiesId[i];
-		Activity* act=NULL;
+		/*Activity* act=NULL;
 		for(Activity* a : qAsConst(gt.rules.activitiesList))
 			if(a->id==id)
-				act=a;
+				act=a;*/
+		Activity* act=gt.rules.activitiesPointerHash.value(id, NULL);
 		
 		if(act!=NULL){
 			//teacher
 			if(tn!=""){
 				bool ok2=false;
-				for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+				for(QStringList::const_iterator it=act->teachersNames.constBegin(); it!=act->teachersNames.constEnd(); it++)
 					if(*it == tn){
 						ok2=true;
 						break;
@@ -178,7 +146,7 @@ bool ConstraintActivitiesSameStartingTimeForm::filterOk(TimeConstraint* ctr)
 				foundSubject=true;
 		
 			//activity tag
-			if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
+			if(atn!="" && !act->activityTagsNames.contains(atn))
 				;
 			else
 				foundActivityTag=true;
@@ -186,7 +154,7 @@ bool ConstraintActivitiesSameStartingTimeForm::filterOk(TimeConstraint* ctr)
 			//students
 			if(stn!=""){
 				bool ok2=false;
-				for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+				for(QStringList::const_iterator it=act->studentsNames.constBegin(); it!=act->studentsNames.constEnd(); it++)
 					if(*it == stn){
 						ok2=true;
 						break;
@@ -243,7 +211,7 @@ void ConstraintActivitiesSameStartingTimeForm::addConstraint()
 	setParentAndOtherThings(&form, this);
 	form.exec();
 
-	this->refreshConstraintsListWidget();
+	this->filterChanged();
 	
 	constraintsListWidget->setCurrentRow(constraintsListWidget->count()-1);
 }
@@ -264,7 +232,7 @@ void ConstraintActivitiesSameStartingTimeForm::modifyConstraint()
 	setParentAndOtherThings(&form, this);
 	form.exec();
 
-	refreshConstraintsListWidget();
+	filterChanged();
 	
 	constraintsListWidget->verticalScrollBar()->setValue(valv);
 	constraintsListWidget->horizontalScrollBar()->setValue(valh);
