@@ -43,10 +43,6 @@ ConstraintActivityEndsStudentsDayForm::ConstraintActivityEndsStudentsDayForm(QWi
 	connect(removeConstraintPushButton, SIGNAL(clicked()), this, SLOT(removeConstraint()));
 	connect(modifyConstraintPushButton, SIGNAL(clicked()), this, SLOT(modifyConstraint()));
 	connect(constraintsListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(modifyConstraint()));
-	connect(teachersComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(studentsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(subjectsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(activityTagsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
 
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
@@ -83,23 +79,15 @@ ConstraintActivityEndsStudentsDayForm::ConstraintActivityEndsStudentsDayForm(QWi
 	activityTagsComboBox->setCurrentIndex(0);
 
 	populateStudentsComboBox(studentsComboBox, QString(""), true);
-	/*studentsComboBox->addItem("");
-	for(int i=0; i<gt.rules.yearsList.size(); i++){
-		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->addItem(sty->name);
-		for(int j=0; j<sty->groupsList.size(); j++){
-			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->addItem(stg->name);
-			if(SHOW_SUBGROUPS_IN_COMBO_BOXES) for(int k=0; k<stg->subgroupsList.size(); k++){
-				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->addItem(sts->name);
-			}
-		}
-	}*/
 	studentsComboBox->setCurrentIndex(0);
 ///////////////
 
 	this->filterChanged();
+
+	connect(teachersComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(studentsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(subjectsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(activityTagsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
 }
 
 ConstraintActivityEndsStudentsDayForm::~ConstraintActivityEndsStudentsDayForm()
@@ -116,16 +104,17 @@ bool ConstraintActivityEndsStudentsDayForm::filterOk(TimeConstraint* ctr)
 	
 	QString tn=teachersComboBox->currentText();
 	QString sbn=subjectsComboBox->currentText();
-	QString sbtn=activityTagsComboBox->currentText();
+	QString atn=activityTagsComboBox->currentText();
 	QString stn=studentsComboBox->currentText();
 		
 	bool found=true;
 	
 	int id=c->activityId;
-	Activity* act=NULL;
+	/*Activity* act=NULL;
 	for(Activity* a : qAsConst(gt.rules.activitiesList))
 		if(a->id==id)
-			act=a;
+			act=a;*/
+	Activity* act=gt.rules.activitiesPointerHash.value(id, NULL);
 
 	found=true;
 		
@@ -133,7 +122,7 @@ bool ConstraintActivityEndsStudentsDayForm::filterOk(TimeConstraint* ctr)
 		//teacher
 		if(tn!=""){
 			bool ok2=false;
-			for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+			for(QStringList::const_iterator it=act->teachersNames.constBegin(); it!=act->teachersNames.constEnd(); it++)
 				if(*it == tn){
 					ok2=true;
 					break;
@@ -147,13 +136,13 @@ bool ConstraintActivityEndsStudentsDayForm::filterOk(TimeConstraint* ctr)
 			found=false;
 	
 		//activity tag
-		if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
+		if(atn!="" && !act->activityTagsNames.contains(atn))
 			found=false;
 	
 		//students
 		if(stn!=""){
 			bool ok2=false;
-			for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+			for(QStringList::const_iterator it=act->studentsNames.constBegin(); it!=act->studentsNames.constEnd(); it++)
 				if(*it == stn){
 					ok2=true;
 					break;
