@@ -415,11 +415,11 @@ void ConstraintMinDaysBetweenActivitiesForm::changeSelectively()
 				}
 			}
 
-		QMessageBox::information(this, tr("FET information"), tr("There were inspected (and possibly modified) %1 constraints min days between activities matching your criteria")
-		 .arg(count)+"\n\n"+
-		 	tr("NOTE: If you are using constraints of type activities same starting time or activities same starting day, it is important"
-		 	 " (after current operation) to apply the operation of removing redundant constraints.")
-		 	+" "+tr("Read Help/Important tips - tip 2) for details.")
+		QMessageBox::information(this, tr("FET information"), tr("There were inspected (and possibly modified) %1 constraints min days between activities"
+		 " matching your criteria").arg(count)+"\n\n"+
+		 tr("NOTE: If you are using constraints of type activities same starting time or activities same starting day, it is important"
+		  " (after current operation) to apply the operation of removing redundant constraints.")
+		 +" "+tr("Read Help/Important tips - tip 2) for details.")
 		 );
 
 		gt.rules.internalStructureComputed=false;
