@@ -43,8 +43,6 @@ ConstraintStudentsSetHomeRoomsForm::ConstraintStudentsSetHomeRoomsForm(QWidget*
 	connect(constraintsListWidget, SIGNAL(currentRowChanged(int)), this, SLOT(constraintChanged(int)));
 	connect(modifyConstraintPushButton, SIGNAL(clicked()), this, SLOT(modifyConstraint()));
 	connect(constraintsListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(modifyConstraint()));
-	connect(studentsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(roomsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
 
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
@@ -56,26 +54,15 @@ ConstraintStudentsSetHomeRoomsForm::ConstraintStudentsSetHomeRoomsForm(QWidget*
 	Q_UNUSED(tmp5);
 	
 	populateStudentsComboBox(studentsComboBox, QString(""), true);
-	/*studentsComboBox->addItem("");
-
-	for(int i=0; i<gt.rules.yearsList.size(); i++){
-		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->addItem(sty->name);
-		for(int j=0; j<sty->groupsList.size(); j++){
-			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->addItem(stg->name);
-			if(SHOW_SUBGROUPS_IN_COMBO_BOXES) for(int k=0; k<stg->subgroupsList.size(); k++){
-				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->addItem(sts->name);
-			}
-		}
-	}*/
 	
 	roomsComboBox->addItem("");
 	for(Room* rm : qAsConst(gt.rules.roomsList))
 		roomsComboBox->addItem(rm->name);
 
-	this->refreshConstraintsListWidget();
+	this->filterChanged();
+
+	connect(studentsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(roomsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
 }
 
 ConstraintStudentsSetHomeRoomsForm::~ConstraintStudentsSetHomeRoomsForm()
@@ -83,7 +70,7 @@ ConstraintStudentsSetHomeRoomsForm::~ConstraintStudentsSetHomeRoomsForm()
 	saveFETDialogGeometry(this);
 }
 
-void ConstraintStudentsSetHomeRoomsForm::refreshConstraintsListWidget()
+void ConstraintStudentsSetHomeRoomsForm::filterChanged()
 {
 	this->visibleConstraintsList.clear();
 	constraintsListWidget->clear();
@@ -103,11 +90,6 @@ void ConstraintStudentsSetHomeRoomsForm::refreshConstraintsListWidget()
 		constraintsListWidget->setCurrentRow(-1);
 }
 
-void ConstraintStudentsSetHomeRoomsForm::filterChanged()
-{
-	this->refreshConstraintsListWidget();
-}
-
 bool ConstraintStudentsSetHomeRoomsForm::filterOk(SpaceConstraint* ctr)
 {
 	if(ctr->type==CONSTRAINT_STUDENTS_SET_HOME_ROOMS){
@@ -139,7 +121,7 @@ void ConstraintStudentsSetHomeRoomsForm::addConstraint()
 	setParentAndOtherThings(&form, this);
 	form.exec();
 
-	this->refreshConstraintsListWidget();
+	this->filterChanged();
 	
 	constraintsListWidget->setCurrentRow(constraintsListWidget->count()-1);
 }
@@ -160,7 +142,7 @@ void ConstraintStudentsSetHomeRoomsForm::modifyConstraint()
 	setParentAndOtherThings(&form, this);
 	form.exec();
 
-	this->refreshConstraintsListWidget();
+	this->filterChanged();
 	
 	constraintsListWidget->verticalScrollBar()->setValue(valv);
 	constraintsListWidget->horizontalScrollBar()->setValue(valh);
