@@ -31,8 +31,6 @@ public:
 	ConstraintSubactivitiesPreferredTimeSlotsForm(QWidget* parent);
 	~ConstraintSubactivitiesPreferredTimeSlotsForm();
 
-	void refreshConstraintsListWidget();
-
 	bool filterOk(TimeConstraint* ctr);
 	
 public slots:
@@ -41,6 +39,8 @@ public slots:
 	void modifyConstraint();
 	void removeConstraint();
 	
+	void filterChanged();
+	
 	void help();
 };
 
