@@ -42,7 +42,7 @@ ConstraintSubjectPreferredRoomsForm::ConstraintSubjectPreferredRoomsForm(QWidget
 	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
 	connect(constraintsListWidget, SIGNAL(currentRowChanged(int)), this, SLOT(constraintChanged(int)));
 	connect(modifyConstraintPushButton, SIGNAL(clicked()), this, SLOT(modifyConstraint()));
-	connect(subjectsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
+
 	connect(constraintsListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(modifyConstraint()));
 
 	centerWidgetOnScreen(this);
@@ -51,13 +51,25 @@ ConstraintSubjectPreferredRoomsForm::ConstraintSubjectPreferredRoomsForm(QWidget
 	QSize tmp3=subjectsComboBox->minimumSizeHint();
 	Q_UNUSED(tmp3);
 	
+	QSize tmp5=roomsComboBox->minimumSizeHint();
+	Q_UNUSED(tmp5);
+	
+	roomsComboBox->addItem("");
+	for(int i=0; i<gt.rules.roomsList.size(); i++){
+		Room* rm=gt.rules.roomsList[i];
+		roomsComboBox->addItem(rm->name);
+	}
+
 	subjectsComboBox->addItem("");
 	for(int i=0; i<gt.rules.subjectsList.size(); i++){
 		Subject* sb=gt.rules.subjectsList[i];
 		subjectsComboBox->addItem(sb->name);
 	}
 
-	this->refreshConstraintsListWidget();
+	this->filterChanged();
+
+	connect(roomsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(subjectsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
 }
 
 ConstraintSubjectPreferredRoomsForm::~ConstraintSubjectPreferredRoomsForm()
@@ -65,7 +77,7 @@ ConstraintSubjectPreferredRoomsForm::~ConstraintSubjectPreferredRoomsForm()
 	saveFETDialogGeometry(this);
 }
 
-void ConstraintSubjectPreferredRoomsForm::refreshConstraintsListWidget()
+void ConstraintSubjectPreferredRoomsForm::filterChanged()
 {
 	this->visibleConstraintsList.clear();
 	constraintsListWidget->clear();
@@ -85,16 +97,12 @@ void ConstraintSubjectPreferredRoomsForm::refreshConstraintsListWidget()
 		this->constraintChanged(-1);
 }
 
-void ConstraintSubjectPreferredRoomsForm::filterChanged()
-{
-	this->refreshConstraintsListWidget();
-}
-
 bool ConstraintSubjectPreferredRoomsForm::filterOk(SpaceConstraint* ctr)
 {
 	if(ctr->type==CONSTRAINT_SUBJECT_PREFERRED_ROOMS){
 		ConstraintSubjectPreferredRooms* c=(ConstraintSubjectPreferredRooms*)ctr;
-		return c->subjectName==subjectsComboBox->currentText() || subjectsComboBox->currentText()=="";
+		return (c->roomsNames.contains(roomsComboBox->currentText()) || roomsComboBox->currentText()=="") &&
+		 (c->subjectName==subjectsComboBox->currentText() || subjectsComboBox->currentText()=="");
 	}
 	else
 		return false;
@@ -120,7 +128,7 @@ void ConstraintSubjectPreferredRoomsForm::addConstraint()
 	setParentAndOtherThings(&form, this);
 	form.exec();
 
-	this->refreshConstraintsListWidget();
+	this->filterChanged();
 	
 	constraintsListWidget->setCurrentRow(constraintsListWidget->count()-1);
 }
@@ -141,7 +149,7 @@ void ConstraintSubjectPreferredRoomsForm::modifyConstraint()
 	setParentAndOtherThings(&form, this);
 	form.exec();
 
-	this->refreshConstraintsListWidget();
+	this->filterChanged();
 	
 	constraintsListWidget->verticalScrollBar()->setValue(valv);
 	constraintsListWidget->horizontalScrollBar()->setValue(valh);
