@@ -43,8 +43,6 @@ ConstraintTeacherHomeRoomsForm::ConstraintTeacherHomeRoomsForm(QWidget* parent):
 	connect(constraintsListWidget, SIGNAL(currentRowChanged(int)), this, SLOT(constraintChanged(int)));
 	connect(modifyConstraintPushButton, SIGNAL(clicked()), this, SLOT(modifyConstraint()));
 	connect(constraintsListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(modifyConstraint()));
-	connect(teachersComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(roomsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
 
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
@@ -63,7 +61,10 @@ ConstraintTeacherHomeRoomsForm::ConstraintTeacherHomeRoomsForm(QWidget* parent):
 	for(Room* rm : qAsConst(gt.rules.roomsList))
 		roomsComboBox->addItem(rm->name);
 
-	this->refreshConstraintsListWidget();
+	this->filterChanged();
+
+	connect(teachersComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(roomsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
 }
 
 ConstraintTeacherHomeRoomsForm::~ConstraintTeacherHomeRoomsForm()
@@ -71,7 +72,7 @@ ConstraintTeacherHomeRoomsForm::~ConstraintTeacherHomeRoomsForm()
 	saveFETDialogGeometry(this);
 }
 
-void ConstraintTeacherHomeRoomsForm::refreshConstraintsListWidget()
+void ConstraintTeacherHomeRoomsForm::filterChanged()
 {
 	this->visibleConstraintsList.clear();
 	constraintsListWidget->clear();
@@ -91,11 +92,6 @@ void ConstraintTeacherHomeRoomsForm::refreshConstraintsListWidget()
 		this->constraintChanged(-1);
 }
 
-void ConstraintTeacherHomeRoomsForm::filterChanged()
-{
-	this->refreshConstraintsListWidget();
-}
-
 bool ConstraintTeacherHomeRoomsForm::filterOk(SpaceConstraint* ctr)
 {
 	if(ctr->type==CONSTRAINT_TEACHER_HOME_ROOMS){
@@ -127,7 +123,7 @@ void ConstraintTeacherHomeRoomsForm::addConstraint()
 	setParentAndOtherThings(&form, this);
 	form.exec();
 
-	this->refreshConstraintsListWidget();
+	this->filterChanged();
 	
 	constraintsListWidget->setCurrentRow(constraintsListWidget->count()-1);
 }
@@ -148,7 +144,7 @@ void ConstraintTeacherHomeRoomsForm::modifyConstraint()
 	setParentAndOtherThings(&form, this);
 	form.exec();
 
-	this->refreshConstraintsListWidget();
+	this->filterChanged();
 	
 	constraintsListWidget->verticalScrollBar()->setValue(valv);
 	constraintsListWidget->horizontalScrollBar()->setValue(valh);
