@@ -42,7 +42,7 @@ ConstraintTeacherMaxHoursContinuouslyForm::ConstraintTeacherMaxHoursContinuously
 	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
 	connect(removeConstraintPushButton, SIGNAL(clicked()), this, SLOT(removeConstraint()));
 	connect(modifyConstraintPushButton, SIGNAL(clicked()), this, SLOT(modifyConstraint()));
-	connect(teachersComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
+
 	connect(constraintsListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(modifyConstraint()));
 
 	centerWidgetOnScreen(this);
@@ -58,6 +58,8 @@ ConstraintTeacherMaxHoursContinuouslyForm::ConstraintTeacherMaxHoursContinuously
 	}
 
 	this->filterChanged();
+
+	connect(teachersComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
 }
 
 ConstraintTeacherMaxHoursContinuouslyForm::~ConstraintTeacherMaxHoursContinuouslyForm()
