@@ -43,7 +43,6 @@ ConstraintTeachersActivityTagMaxHoursContinuouslyForm::ConstraintTeachersActivit
 	connect(removeConstraintPushButton, SIGNAL(clicked()), this, SLOT(removeConstraint()));
 	connect(modifyConstraintPushButton, SIGNAL(clicked()), this, SLOT(modifyConstraint()));
 	connect(constraintsListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(modifyConstraint()));
-	connect(activityTagsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
 
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
@@ -57,6 +56,8 @@ ConstraintTeachersActivityTagMaxHoursContinuouslyForm::ConstraintTeachersActivit
 		activityTagsComboBox->addItem(at->name);
 
 	this->filterChanged();
+
+	connect(activityTagsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
 }
 
 ConstraintTeachersActivityTagMaxHoursContinuouslyForm::~ConstraintTeachersActivityTagMaxHoursContinuouslyForm()
