@@ -328,6 +328,10 @@ void usage(QTextStream* out, const QString& error)
 		"\t\tWANFTFS is either true or false, represents whether you want the program to issue a warning if you are using activites which are not fixed in time, "
 		"but are fixed in space in a virtual room, specifying also the real rooms (which is not recommended) (default true).\n"
 		"\n"
+		"\t--warnifusingmaxhoursdailywithlessthan100percentweight=WMHDWLT100PW\n"
+		"\t\tWMHDWLT100PW is either true or false, represents whether you want the program to issue a warning if you are using constraints of type teacher(s)/students (set) "
+		"max hours daily with a weight less than 100% (default true).\n"
+		"\n"
 		"\t--verbose=VBS\n"
 		"\t\tVBS is either true or false, represents whether you want additional generation messages and other messages to be shown on the command line (default false).\n"
 		"\n"
@@ -468,6 +472,7 @@ void readSimulationParameters()
 	SHOW_WARNING_FOR_NOT_PERFECT_CONSTRAINTS=newSettings.value("warn-if-using-not-perfect-constraints", "true").toBool();
 	SHOW_WARNING_FOR_SUBGROUPS_WITH_THE_SAME_ACTIVITIES=newSettings.value("warn-subgroups-with-the-same-activities", "true").toBool();
 	SHOW_WARNING_FOR_ACTIVITIES_FIXED_SPACE_VIRTUAL_REAL_ROOMS_BUT_NOT_FIXED_TIME=newSettings.value("warn-activities-not-fixed-time-fixed-space-virtual-real", "true").toBool();
+	SHOW_WARNING_FOR_MAX_HOURS_DAILY_WITH_UNDER_100_WEIGHT=newSettings.value("warn-max-hours-daily-with-under-100-weight", "true").toBool();
 	ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS=newSettings.value("enable-students-min-hours-daily-with-allow-empty-days", "false").toBool();
 	SHOW_WARNING_FOR_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS=newSettings.value("warn-if-using-students-min-hours-daily-with-allow-empty-days", "true").toBool();
 	
@@ -485,6 +490,13 @@ void readSimulationParameters()
 
 	SHOW_TOOLTIPS_FOR_CONSTRAINTS_WITH_TABLES=newSettings.value("FetMainForm/show-tooltips-for-constraints-with-tables", "false").toBool();
 	
+	BEEP_AT_END_OF_GENERATION=newSettings.value("beep-at-the-end-of-generation", "true").toBool();
+	ENABLE_COMMAND_AT_END_OF_GENERATION=newSettings.value("enable-command-at-the-end-of-generation", "false").toBool();
+	commandAtEndOfGeneration=newSettings.value("command-at-the-end-of-generation", "").toString();
+//	DETACHED_NOTIFICATION=newSettings.value("detached-notification", "false").toBool();
+//	terminateCommandAfterSeconds=newSettings.value("terminate-command-at-the-end-of-generation-after-seconds", "0").toInt();
+//	killCommandAfterSeconds=newSettings.value("kill-command-at-the-end-of-generation-after-seconds", "0").toInt();
+	
 	if(VERBOSE){
 		cout<<"Settings read"<<endl;
 	}
@@ -549,6 +561,7 @@ void writeSimulationParameters()
 	settings.setValue("warn-if-using-not-perfect-constraints", SHOW_WARNING_FOR_NOT_PERFECT_CONSTRAINTS);
 	settings.setValue("warn-subgroups-with-the-same-activities", SHOW_WARNING_FOR_SUBGROUPS_WITH_THE_SAME_ACTIVITIES);
 	settings.setValue("warn-activities-not-fixed-time-fixed-space-virtual-real", SHOW_WARNING_FOR_ACTIVITIES_FIXED_SPACE_VIRTUAL_REAL_ROOMS_BUT_NOT_FIXED_TIME);
+	settings.setValue("warn-max-hours-daily-with-under-100-weight", SHOW_WARNING_FOR_MAX_HOURS_DAILY_WITH_UNDER_100_WEIGHT);
 	settings.setValue("enable-students-min-hours-daily-with-allow-empty-days", ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS);
 	settings.setValue("warn-if-using-students-min-hours-daily-with-allow-empty-days", SHOW_WARNING_FOR_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS);
 
@@ -564,6 +577,14 @@ void writeSimulationParameters()
 	settings.setValue("FetMainForm/show-shortcuts", SHOW_SHORTCUTS_ON_MAIN_WINDOW);
 
 	settings.setValue("FetMainForm/show-tooltips-for-constraints-with-tables", SHOW_TOOLTIPS_FOR_CONSTRAINTS_WITH_TABLES);
+
+	settings.setValue("beep-at-the-end-of-generation", BEEP_AT_END_OF_GENERATION);
+	settings.setValue("enable-command-at-the-end-of-generation", ENABLE_COMMAND_AT_END_OF_GENERATION);
+	settings.setValue("command-at-the-end-of-generation", commandAtEndOfGeneration);
+//	settings.setValue("detached-notification", DETACHED_NOTIFICATION);
+//	settings.setValue("terminate-command-at-the-end-of-generation-after-seconds", terminateCommandAfterSeconds);
+//	settings.setValue("kill-command-at-the-end-of-generation-after-seconds", killCommandAfterSeconds);
+	
 }
 #endif
 
@@ -921,6 +942,8 @@ int main(int argc, char **argv)
 
 		setLanguage(qapplication, NULL);
 
+		QCoreApplication::setApplicationName(FetTranslate::tr("FET"));
+
 		pqapplication=&qapplication;
 		FetMainForm fetMainForm;
 		pFetMainForm=&fetMainForm;
@@ -947,6 +970,7 @@ int main(int argc, char **argv)
 #else
 	/////////////////////////////////////////////////
 	//begin command line
+	
 	if(_args.count()>1){
 		bool showHelp=false;
 	
@@ -1023,6 +1047,8 @@ int main(int argc, char **argv)
 		SHOW_WARNING_FOR_SUBGROUPS_WITH_THE_SAME_ACTIVITIES=true;
 		
 		SHOW_WARNING_FOR_ACTIVITIES_FIXED_SPACE_VIRTUAL_REAL_ROOMS_BUT_NOT_FIXED_TIME=true;
+
+		SHOW_WARNING_FOR_MAX_HOURS_DAILY_WITH_UNDER_100_WEIGHT=true;
 		
 		SHOW_WARNING_FOR_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS=true;
 		
@@ -1153,6 +1179,10 @@ int main(int argc, char **argv)
 				if(s.right(5)=="false")
 					SHOW_WARNING_FOR_ACTIVITIES_FIXED_SPACE_VIRTUAL_REAL_ROOMS_BUT_NOT_FIXED_TIME=false;
 			}
+			else if(s.left(55)=="--warnifusingmaxhoursdailywithlessthan100percentweight="){
+				if(s.right(5)=="false")
+					SHOW_WARNING_FOR_MAX_HOURS_DAILY_WITH_UNDER_100_WEIGHT=false;
+			}
 			else if(s.left(43)=="--warnifusinggroupactivitiesininitialorder="){
 				if(s.right(5)=="false")
 					SHOW_WARNING_FOR_GROUP_ACTIVITIES_IN_INITIAL_ORDER=false;
@@ -1393,10 +1423,16 @@ int main(int argc, char **argv)
 		
 		setLanguage(qCoreApplication, NULL);
 		
+		QCoreApplication::setApplicationName(FetTranslate::tr("FET-CL"));
+		
 		QFile maxPlacedActivityFile(logsDir+"max_placed_activities.txt");
 		maxPlacedActivityFile.open(QIODevice::WriteOnly);
 		QTextStream maxPlacedActivityStream(&maxPlacedActivityFile);
+#if QT_VERSION >= QT_VERSION_CHECK(6,0,0)
+		maxPlacedActivityStream.setEncoding(QStringConverter::Utf8);
+#else
 		maxPlacedActivityStream.setCodec("UTF-8");
+#endif
 		maxPlacedActivityStream.setGenerateByteOrderMark(true);
 #if QT_VERSION >= QT_VERSION_CHECK(5,15,0)
 		maxPlacedActivityStream<<FetTranslate::tr("This is the list of max placed activities, chronologically. If FET could reach maximum n-th activity, look at the n+1-st activity"
@@ -1405,13 +1441,17 @@ int main(int argc, char **argv)
 		maxPlacedActivityStream<<FetTranslate::tr("This is the list of max placed activities, chronologically. If FET could reach maximum n-th activity, look at the n+1-st activity"
 			" in the initial order of the activities")<<endl<<endl;
 #endif
-				
+		
 		QFile initialOrderFile(logsDir+"initial_order.txt");
 		initialOrderFile.open(QIODevice::WriteOnly);
 		QTextStream initialOrderStream(&initialOrderFile);
+#if QT_VERSION >= QT_VERSION_CHECK(6,0,0)
+		initialOrderStream.setEncoding(QStringConverter::Utf8);
+#else
 		initialOrderStream.setCodec("UTF-8");
+#endif
 		initialOrderStream.setGenerateByteOrderMark(true);
-						
+		
 #if QT_VERSION >= QT_VERSION_CHECK(5,15,0)
 		out<<"This file contains the result (log) of last operation"<<Qt::endl<<Qt::endl;
 #else
@@ -1753,7 +1793,11 @@ int main(int argc, char **argv)
 				return 1;
 			}
 			QTextStream difficultActivitiesOut(&difficultActivitiesFile);
+#if QT_VERSION >= QT_VERSION_CHECK(6,0,0)
+			difficultActivitiesOut.setEncoding(QStringConverter::Utf8);
+#else
 			difficultActivitiesOut.setCodec("UTF-8");
+#endif
 			difficultActivitiesOut.setGenerateByteOrderMark(true);
 			
 #if QT_VERSION >= QT_VERSION_CHECK(5,15,0)
@@ -1889,7 +1933,11 @@ int main(int argc, char **argv)
 				return 1;
 			}
 			QTextStream difficultActivitiesOut(&difficultActivitiesFile);
+#if QT_VERSION >= QT_VERSION_CHECK(6,0,0)
+			difficultActivitiesOut.setEncoding(QStringConverter::Utf8);
+#else
 			difficultActivitiesOut.setCodec("UTF-8");
+#endif
 			difficultActivitiesOut.setGenerateByteOrderMark(true);
 			
 #if QT_VERSION >= QT_VERSION_CHECK(5,15,0)
