@@ -167,6 +167,8 @@ public slots:
 	void on_studentsComboBoxesStyleAction_triggered();
 	
 	void on_settingsShowVirtualRoomsInTimetablesAction_toggled();
+
+	void on_settingsCommandAfterFinishingAction_triggered();
 	///
 
 	//////confirmations
@@ -180,6 +182,8 @@ public slots:
 
 	void showWarningForActivitiesNotLockedTimeLockedSpaceVirtualRealRoomsToggled(bool checked);
 	
+	void showWarningForMaxHoursDailyWithUnder100WeightToggled(bool checked);
+	
 	void enableActivityTagMaxHoursDailyToggled(bool checked);
 	void enableActivityTagMinHoursDailyToggled(bool checked);
 	void enableStudentsMaxGapsPerDayToggled(bool checked);
