@@ -28,7 +28,7 @@
 #include <QAbstractItemView>
 
 #include <algorithm>
-using namespace std;
+//using namespace std;
 
 GroupActivitiesInInitialOrderItemsForm::GroupActivitiesInInitialOrderItemsForm(QWidget* parent): QDialog(parent)
 {
@@ -46,10 +46,7 @@ GroupActivitiesInInitialOrderItemsForm::GroupActivitiesInInitialOrderItemsForm(Q
 	connect(removeItemPushButton, SIGNAL(clicked()), this, SLOT(removeItem()));
 	connect(modifyItemPushButton, SIGNAL(clicked()), this, SLOT(modifyItem()));
 	connect(itemsListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(modifyItem()));
-	connect(teachersComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(studentsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(subjectsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(activityTagsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
+
 	connect(helpPushButton, SIGNAL(clicked()), this, SLOT(help()));
 	
 	connect(sortByCommentsPushButton, SIGNAL(clicked()), this, SLOT(sortItemsByComments()));
@@ -92,23 +89,15 @@ GroupActivitiesInInitialOrderItemsForm::GroupActivitiesInInitialOrderItemsForm(Q
 	activityTagsComboBox->setCurrentIndex(0);
 
 	populateStudentsComboBox(studentsComboBox, QString(""), true);
-	/*studentsComboBox->addItem("");
-	for(int i=0; i<gt.rules.yearsList.size(); i++){
-		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->addItem(sty->name);
-		for(int j=0; j<sty->groupsList.size(); j++){
-			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->addItem(stg->name);
-			if(SHOW_SUBGROUPS_IN_COMBO_BOXES) for(int k=0; k<stg->subgroupsList.size(); k++){
-				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->addItem(sts->name);
-			}
-		}
-	}*/
 	studentsComboBox->setCurrentIndex(0);
 ///////////////
 
 	this->filterChanged();
+
+	connect(teachersComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(studentsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(subjectsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(activityTagsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
 }
 
 GroupActivitiesInInitialOrderItemsForm::~GroupActivitiesInInitialOrderItemsForm()
@@ -120,26 +109,27 @@ bool GroupActivitiesInInitialOrderItemsForm::filterOk(const GroupActivitiesInIni
 {
 	QString tn=teachersComboBox->currentText();
 	QString sbn=subjectsComboBox->currentText();
-	QString sbtn=activityTagsComboBox->currentText();
+	QString atn=activityTagsComboBox->currentText();
 	QString stn=studentsComboBox->currentText();
 	
-	if(tn=="" && sbn=="" && sbtn=="" && stn=="")
+	if(tn=="" && sbn=="" && atn=="" && stn=="")
 		return true;
 	
 	bool foundTeacher=false, foundStudents=false, foundSubject=false, foundActivityTag=false;
 		
 	for(int i=0; i<item.ids.count(); i++){
 		int id=item.ids.at(i);
-		Activity* act=NULL;
+		/*Activity* act=NULL;
 		for(Activity* a : qAsConst(gt.rules.activitiesList))
 			if(a->id==id)
-				act=a;
+				act=a;*/
+		Activity* act=gt.rules.activitiesPointerHash.value(id, NULL);
 		
 		if(act!=NULL){
 			//teacher
 			if(tn!=""){
 				bool ok2=false;
-				for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+				for(QStringList::const_iterator it=act->teachersNames.constBegin(); it!=act->teachersNames.constEnd(); it++)
 					if(*it == tn){
 						ok2=true;
 						break;
@@ -157,7 +147,7 @@ bool GroupActivitiesInInitialOrderItemsForm::filterOk(const GroupActivitiesInIni
 				foundSubject=true;
 		
 			//activity tag
-			if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
+			if(atn!="" && !act->activityTagsNames.contains(atn))
 				;
 			else
 				foundActivityTag=true;
@@ -165,7 +155,7 @@ bool GroupActivitiesInInitialOrderItemsForm::filterOk(const GroupActivitiesInIni
 			//students
 			if(stn!=""){
 				bool ok2=false;
-				for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+				for(QStringList::const_iterator it=act->studentsNames.constBegin(); it!=act->studentsNames.constEnd(); it++)
 					if(*it == stn){
 						ok2=true;
 						break;
