@@ -78,7 +78,7 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	 "or a combination of these), %2 are the copyright holders").arg("2002-2020").arg("Liviu Lalescu, Volker Dirr");
 	about+="<br /><br />";
 	about+=tr("Version: %1 (%2 %3).", "%1 is the current FET version, %2 is the current release month, %3 is the current release year").arg(FET_VERSION)
-	 .arg(QCoreApplication::translate("MonthsNames", "April")).arg("2020");
+	 .arg(QCoreApplication::translate("MonthsNames", "December")).arg("2020");
 	about+="<br /><br />";
 	about+=tr("Licensed under the GNU Affero General Public License version 3 or later.");
 	about+="<br /><br />";
@@ -959,6 +959,46 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	thanksTo+=QString("<br />");
 	thanksTo+=QString("Pierre L'Ecuyer");
 	thanksTo+=QString("<br />");
+	thanksTo+=QString("Francesco Rizzo");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Peter Johnson");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("bilal24");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Mohamed Ait Ichou");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("yassine bigman");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Eric Carolus");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Bouhadef");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("saidmechri");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Med BENNIOU");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("mathmake");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("mikkojoo");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("samantha.goddard");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("lakhdar bezzit");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Hiba Hadi");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Marcus");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Celia22");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Fiorellino");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("saladv");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Fran");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Nando");
+	thanksTo+=QString("<br />");
 
 	thanksToTextBrowser->setHtml(thanksTo);
 }
