@@ -235,17 +235,17 @@ ModifyActivityForm::ModifyActivityForm(QWidget* parent, int id, int activityGrou
 	updateActivityTagsListWidget();
 
 	//after updateSubjectsComboBox
-	connect(subjectsComboBox, SIGNAL(activated(QString)), this, SLOT(updateAllTeachersListWidget()));
+	connect(subjectsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(updateAllTeachersListWidget()));
 	connect(allTeachersRadioButton, SIGNAL(toggled(bool)), this, SLOT(allTeachersRadioButtonToggled(bool)));
 	connect(qualifiedTeachersRadioButton, SIGNAL(toggled(bool)), this, SLOT(qualifiedTeachersRadioButtonToggled(bool)));
 	updateAllTeachersListWidget();
 	
 	selectedTeachersListWidget->clear();
-	for(QStringList::Iterator it=this->_teachers.begin(); it!=this->_teachers.end(); it++)
+	for(QStringList::const_iterator it=this->_teachers.constBegin(); it!=this->_teachers.constEnd(); it++)
 		selectedTeachersListWidget->addItem(*it);
 	
 	selectedStudentsListWidget->clear();
-	for(QStringList::Iterator it=this->_students.begin(); it!=this->_students.end(); it++)
+	for(QStringList::const_iterator it=this->_students.constBegin(); it!=this->_students.constEnd(); it++)
 		selectedStudentsListWidget->addItem(*it);
 
 	for(int i=0; i<MAX_SPLIT_OF_AN_ACTIVITY; i++)
@@ -417,7 +417,7 @@ void ModifyActivityForm::updateActivityTagsListWidget()
 	}
 		
 	selectedActivityTagsListWidget->clear();
-	for(QStringList::Iterator it=this->_activityTags.begin(); it!=this->_activityTags.end(); it++)
+	for(QStringList::const_iterator it=this->_activityTags.constBegin(); it!=this->_activityTags.constEnd(); it++)
 		selectedActivityTagsListWidget->addItem(*it);
 }
 
