@@ -58,11 +58,14 @@ public:
 	~ModifyActivityForm();
 
 	void updateStudentsListWidget();
-	void updateTeachersListWidget();
 	void updateSubjectsComboBox();
 	void updateActivityTagsListWidget();
 	
 public slots:
+	void allTeachersRadioButtonToggled(bool checked);
+	void qualifiedTeachersRadioButtonToggled(bool checked);
+	void updateAllTeachersListWidget();
+
 	void ok();
 	void cancel();
 
