@@ -15,6 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <Qt>
+
 #include <QMessageBox>
 
 #include "tablewidgetupdatebug.h"
@@ -68,14 +70,13 @@ ModifyConstraintRoomNotAvailableTimesForm::ModifyConstraintRoomNotAvailableTimes
 		notAllowedTimesTable->setVerticalHeaderItem(i, item);
 	}
 
-	//bool currentMatrix[MAX_HOURS_PER_DAY][MAX_DAYS_PER_WEEK];
 	Matrix2D<bool> currentMatrix;
 	currentMatrix.resize(gt.rules.nHoursPerDay, gt.rules.nDaysPerWeek);
 	
 	for(int i=0; i<gt.rules.nHoursPerDay; i++)
 		for(int j=0; j<gt.rules.nDaysPerWeek; j++)
-			currentMatrix[i][j]=false;			
-	assert(ctr->days.count()==ctr->hours.count());	
+			currentMatrix[i][j]=false;
+	assert(ctr->days.count()==ctr->hours.count());
 	for(int k=0; k<ctr->days.count(); k++){
 		if(ctr->hours.at(k)==-1 || ctr->days.at(k)==-1)
 			assert(0);
@@ -122,11 +123,19 @@ ModifyConstraintRoomNotAvailableTimesForm::~ModifyConstraintRoomNotAvailableTime
 void ModifyConstraintRoomNotAvailableTimesForm::colorItem(QTableWidgetItem* item)
 {
 	if(USE_GUI_COLORS){
+#if QT_VERSION >= QT_VERSION_CHECK(5,14,0)
+		if(item->text()==NO)
+			item->setBackground(QBrush(QColorConstants::DarkGreen));
+		else
+			item->setBackground(QBrush(QColorConstants::DarkRed));
+		item->setForeground(QBrush(QColorConstants::LightGray));
+#else
 		if(item->text()==NO)
 			item->setBackground(QBrush(Qt::darkGreen));
 		else
 			item->setBackground(QBrush(Qt::darkRed));
 		item->setForeground(QBrush(Qt::lightGray));
+#endif
 	}
 }
 
