@@ -39,8 +39,6 @@ ModifyConstraintStudentsMaxBuildingChangesPerDayForm::ModifyConstraintStudentsMa
 	maxChangesSpinBox->setMinimum(0);
 	maxChangesSpinBox->setMaximum(gt.rules.nHoursPerDay);
 	maxChangesSpinBox->setValue(ctr->maxBuildingChangesPerDay);
-		
-	constraintChanged();
 }
 
 ModifyConstraintStudentsMaxBuildingChangesPerDayForm::~ModifyConstraintStudentsMaxBuildingChangesPerDayForm()
@@ -48,10 +46,6 @@ ModifyConstraintStudentsMaxBuildingChangesPerDayForm::~ModifyConstraintStudentsM
 	saveFETDialogGeometry(this);
 }
 
-void ModifyConstraintStudentsMaxBuildingChangesPerDayForm::constraintChanged()
-{
-}
-
 void ModifyConstraintStudentsMaxBuildingChangesPerDayForm::ok()
 {
 	double weight;
