@@ -31,7 +31,7 @@ ModifyConstraintStudentsMaxBuildingChangesPerWeekForm::ModifyConstraintStudentsM
 
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
-		
+	
 	this->_ctr=ctr;
 	
 	weightLineEdit->setText(CustomFETString::number(ctr->weightPercentage));
@@ -39,8 +39,6 @@ ModifyConstraintStudentsMaxBuildingChangesPerWeekForm::ModifyConstraintStudentsM
 	maxChangesSpinBox->setMinimum(0);
 	maxChangesSpinBox->setMaximum(gt.rules.nDaysPerWeek*gt.rules.nHoursPerDay);
 	maxChangesSpinBox->setValue(ctr->maxBuildingChangesPerWeek);
-		
-	constraintChanged();
 }
 
 ModifyConstraintStudentsMaxBuildingChangesPerWeekForm::~ModifyConstraintStudentsMaxBuildingChangesPerWeekForm()
@@ -48,10 +46,6 @@ ModifyConstraintStudentsMaxBuildingChangesPerWeekForm::~ModifyConstraintStudents
 	saveFETDialogGeometry(this);
 }
 
-void ModifyConstraintStudentsMaxBuildingChangesPerWeekForm::constraintChanged()
-{
-}
-
 void ModifyConstraintStudentsMaxBuildingChangesPerWeekForm::ok()
 {
 	double weight;
