@@ -39,8 +39,6 @@ ModifyConstraintStudentsMaxDaysPerWeekForm::ModifyConstraintStudentsMaxDaysPerWe
 	updateMaxDaysSpinBox();
 
 	maxDaysSpinBox->setValue(ctr->maxDaysPerWeek);
-	
-	constraintChanged();
 }
 
 ModifyConstraintStudentsMaxDaysPerWeekForm::~ModifyConstraintStudentsMaxDaysPerWeekForm()
@@ -49,14 +47,10 @@ ModifyConstraintStudentsMaxDaysPerWeekForm::~ModifyConstraintStudentsMaxDaysPerW
 }
 
 void ModifyConstraintStudentsMaxDaysPerWeekForm::updateMaxDaysSpinBox(){
-	maxDaysSpinBox->setMinimum(0);
+	maxDaysSpinBox->setMinimum(1);
 	maxDaysSpinBox->setMaximum(gt.rules.nDaysPerWeek);
 }
 
-void ModifyConstraintStudentsMaxDaysPerWeekForm::constraintChanged()
-{
-}
-
 void ModifyConstraintStudentsMaxDaysPerWeekForm::ok()
 {
 	double weight;
