@@ -31,16 +31,14 @@ ModifyConstraintStudentsMinGapsBetweenBuildingChangesForm::ModifyConstraintStude
 
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
-		
+	
 	this->_ctr=ctr;
 	
 	weightLineEdit->setText(CustomFETString::number(ctr->weightPercentage));
 	
 	minGapsSpinBox->setMinimum(1);
 	minGapsSpinBox->setMaximum(gt.rules.nHoursPerDay);
-	minGapsSpinBox->setValue(ctr->minGapsBetweenBuildingChanges);	
-		
-	constraintChanged();
+	minGapsSpinBox->setValue(ctr->minGapsBetweenBuildingChanges);
 }
 
 ModifyConstraintStudentsMinGapsBetweenBuildingChangesForm::~ModifyConstraintStudentsMinGapsBetweenBuildingChangesForm()
@@ -48,10 +46,6 @@ ModifyConstraintStudentsMinGapsBetweenBuildingChangesForm::~ModifyConstraintStud
 	saveFETDialogGeometry(this);
 }
 
-void ModifyConstraintStudentsMinGapsBetweenBuildingChangesForm::constraintChanged()
-{
-}
-
 void ModifyConstraintStudentsMinGapsBetweenBuildingChangesForm::ok()
 {
 	double weight;
