@@ -53,8 +53,6 @@ ModifyConstraintTeacherMaxGapsPerDayForm::ModifyConstraintTeacherMaxGapsPerDayFo
 	}
 	assert(j>=0);
 	teachersComboBox->setCurrentIndex(j);
-
-	constraintChanged();
 }
 
 ModifyConstraintTeacherMaxGapsPerDayForm::~ModifyConstraintTeacherMaxGapsPerDayForm()
@@ -62,10 +60,6 @@ ModifyConstraintTeacherMaxGapsPerDayForm::~ModifyConstraintTeacherMaxGapsPerDayF
 	saveFETDialogGeometry(this);
 }
 
-void ModifyConstraintTeacherMaxGapsPerDayForm::constraintChanged()
-{
-}
-
 void ModifyConstraintTeacherMaxGapsPerDayForm::ok()
 {
 	double weight;
