@@ -53,8 +53,6 @@ ModifyConstraintTeacherMaxGapsPerWeekForm::ModifyConstraintTeacherMaxGapsPerWeek
 	}
 	assert(j>=0);
 	teachersComboBox->setCurrentIndex(j);
-
-	constraintChanged();
 }
 
 ModifyConstraintTeacherMaxGapsPerWeekForm::~ModifyConstraintTeacherMaxGapsPerWeekForm()
@@ -62,10 +60,6 @@ ModifyConstraintTeacherMaxGapsPerWeekForm::~ModifyConstraintTeacherMaxGapsPerWee
 	saveFETDialogGeometry(this);
 }
 
-void ModifyConstraintTeacherMaxGapsPerWeekForm::constraintChanged()
-{
-}
-
 void ModifyConstraintTeacherMaxGapsPerWeekForm::ok()
 {
 	double weight;
