@@ -57,8 +57,6 @@ ModifyConstraintTeacherMinHoursDailyForm::ModifyConstraintTeacherMinHoursDailyFo
 	}
 	assert(j>=0);
 	teachersComboBox->setCurrentIndex(j);
-
-	constraintChanged();
 }
 
 ModifyConstraintTeacherMinHoursDailyForm::~ModifyConstraintTeacherMinHoursDailyForm()
@@ -71,10 +69,6 @@ void ModifyConstraintTeacherMinHoursDailyForm::updateMinHoursSpinBox(){
 	minHoursSpinBox->setMaximum(gt.rules.nHoursPerDay);	
 }
 
-void ModifyConstraintTeacherMinHoursDailyForm::constraintChanged()
-{
-}
-
 void ModifyConstraintTeacherMinHoursDailyForm::ok()
 {
 	double weight;
