@@ -55,8 +55,6 @@ ModifyConstraintTeacherMinRestingHoursForm::ModifyConstraintTeacherMinRestingHou
 	}
 	assert(j>=0);
 	teachersComboBox->setCurrentIndex(j);
-
-	constraintChanged();
 }
 
 ModifyConstraintTeacherMinRestingHoursForm::~ModifyConstraintTeacherMinRestingHoursForm()
@@ -64,10 +62,6 @@ ModifyConstraintTeacherMinRestingHoursForm::~ModifyConstraintTeacherMinRestingHo
 	saveFETDialogGeometry(this);
 }
 
-void ModifyConstraintTeacherMinRestingHoursForm::constraintChanged()
-{
-}
-
 void ModifyConstraintTeacherMinRestingHoursForm::ok()
 {
 	double weight;
