@@ -32,10 +32,8 @@ public:
 	~ModifyConstraintTeachersIntervalMaxDaysPerWeekForm();
 
 	void updateMaxDaysSpinBox();
-//	void updateTeachersComboBox();
 
 public slots:
-	void constraintChanged();
 	void ok();
 	void cancel();
 };
