@@ -39,8 +39,6 @@ ModifyConstraintTeachersMaxBuildingChangesPerWeekForm::ModifyConstraintTeachersM
 	maxChangesSpinBox->setMinimum(0);
 	maxChangesSpinBox->setMaximum(gt.rules.nDaysPerWeek*gt.rules.nHoursPerDay);
 	maxChangesSpinBox->setValue(ctr->maxBuildingChangesPerWeek);
-		
-	constraintChanged();
 }
 
 ModifyConstraintTeachersMaxBuildingChangesPerWeekForm::~ModifyConstraintTeachersMaxBuildingChangesPerWeekForm()
@@ -48,10 +46,6 @@ ModifyConstraintTeachersMaxBuildingChangesPerWeekForm::~ModifyConstraintTeachers
 	saveFETDialogGeometry(this);
 }
 
-void ModifyConstraintTeachersMaxBuildingChangesPerWeekForm::constraintChanged()
-{
-}
-
 void ModifyConstraintTeachersMaxBuildingChangesPerWeekForm::ok()
 {
 	double weight;
