@@ -39,8 +39,6 @@ ModifyConstraintTeachersMaxDaysPerWeekForm::ModifyConstraintTeachersMaxDaysPerWe
 	updateMaxDaysSpinBox();
 	
 	maxDaysSpinBox->setValue(ctr->maxDaysPerWeek);
-
-	constraintChanged();
 }
 
 ModifyConstraintTeachersMaxDaysPerWeekForm::~ModifyConstraintTeachersMaxDaysPerWeekForm()
@@ -53,10 +51,6 @@ void ModifyConstraintTeachersMaxDaysPerWeekForm::updateMaxDaysSpinBox(){
 	maxDaysSpinBox->setMaximum(gt.rules.nDaysPerWeek);
 }
 
-void ModifyConstraintTeachersMaxDaysPerWeekForm::constraintChanged()
-{
-}
-
 void ModifyConstraintTeachersMaxDaysPerWeekForm::ok()
 {
 	double weight;
