@@ -33,10 +33,8 @@ public:
 	~ModifyConstraintTeachersMaxDaysPerWeekForm();
 
 	void updateMaxDaysSpinBox();
-	//void updateTeachersComboBox();
 
 public slots:
-	void constraintChanged();
 	void ok();
 	void cancel();
 };
