@@ -31,16 +31,14 @@ ModifyConstraintTeachersMinGapsBetweenBuildingChangesForm::ModifyConstraintTeach
 
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
-		
+	
 	this->_ctr=ctr;
 	
 	weightLineEdit->setText(CustomFETString::number(ctr->weightPercentage));
 	
 	minGapsSpinBox->setMinimum(1);
 	minGapsSpinBox->setMaximum(gt.rules.nHoursPerDay);
-	minGapsSpinBox->setValue(ctr->minGapsBetweenBuildingChanges);	
-		
-	constraintChanged();
+	minGapsSpinBox->setValue(ctr->minGapsBetweenBuildingChanges);
 }
 
 ModifyConstraintTeachersMinGapsBetweenBuildingChangesForm::~ModifyConstraintTeachersMinGapsBetweenBuildingChangesForm()
@@ -48,10 +46,6 @@ ModifyConstraintTeachersMinGapsBetweenBuildingChangesForm::~ModifyConstraintTeac
 	saveFETDialogGeometry(this);
 }
 
-void ModifyConstraintTeachersMinGapsBetweenBuildingChangesForm::constraintChanged()
-{
-}
-
 void ModifyConstraintTeachersMinGapsBetweenBuildingChangesForm::ok()
 {
 	double weight;
