@@ -84,7 +84,7 @@ void SettingsTimetableHtmlLevelForm::ok()
 	
 	assert(level>=0);
 
-	if(level>=3){
+	/*if(level>=3){
 		int t=QMessageBox::information(this, tr("FET information"), tr("This level might generate very large timetables, maybe 1 MB per file"
 		 " and 20 MB for all files of a timetable or even more."
 		 " Are you sure you have enough disk space?"),
@@ -92,7 +92,7 @@ void SettingsTimetableHtmlLevelForm::ok()
 		
 		if(t==QMessageBox::Cancel)
 			return;
-	}
+	}*/
 	
 	TIMETABLE_HTML_LEVEL=level;
 	
