@@ -45,6 +45,11 @@
 #include <QPrinter>
 #include <QPrintDialog>
 #include <QPrintPreviewDialog>
+
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,2)
+#include <QPageSize>
+#endif
+
 #endif
 
 extern Timetable gt;
@@ -59,9 +64,15 @@ extern const QString PROGRAM;
 #ifdef QT_NO_PRINTER
 static QMap<LocaleString, int> paperSizesMap;
 #else
+
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,2)
+static QMap<LocaleString, QPageSize> paperSizesMap;
+#else
 static QMap<LocaleString, QPrinter::PaperSize> paperSizesMap;
 #endif
 
+#endif
+
 //const QString CBTablesState="/timetables-combo-box-state";
 
 const QString studentSubjectRBState="/student-subject-state-radio-button-state";
@@ -192,6 +203,39 @@ StatisticsPrintForm::StatisticsPrintForm(QWidget *parent): QDialog(parent){
 #ifdef QT_NO_PRINTER
 	paperSizesMap.insert(tr("Custom", "Type of paper size"), 30);
 #else
+
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,2)
+	paperSizesMap.insert(tr("A0", "Type of paper size"), QPageSize(QPageSize::A0));
+	paperSizesMap.insert(tr("A1", "Type of paper size"), QPageSize(QPageSize::A1));
+	paperSizesMap.insert(tr("A2", "Type of paper size"), QPageSize(QPageSize::A2));
+	paperSizesMap.insert(tr("A3", "Type of paper size"), QPageSize(QPageSize::A3));
+	paperSizesMap.insert(tr("A4", "Type of paper size"), QPageSize(QPageSize::A4));
+	paperSizesMap.insert(tr("A5", "Type of paper size"), QPageSize(QPageSize::A5));
+	paperSizesMap.insert(tr("A6", "Type of paper size"), QPageSize(QPageSize::A6));
+	paperSizesMap.insert(tr("A7", "Type of paper size"), QPageSize(QPageSize::A7));
+	paperSizesMap.insert(tr("A8", "Type of paper size"), QPageSize(QPageSize::A8));
+	paperSizesMap.insert(tr("A9", "Type of paper size"), QPageSize(QPageSize::A9));
+	paperSizesMap.insert(tr("B0", "Type of paper size"), QPageSize(QPageSize::B0));
+	paperSizesMap.insert(tr("B1", "Type of paper size"), QPageSize(QPageSize::B1));
+	paperSizesMap.insert(tr("B2", "Type of paper size"), QPageSize(QPageSize::B2));
+	paperSizesMap.insert(tr("B3", "Type of paper size"), QPageSize(QPageSize::B3));
+	paperSizesMap.insert(tr("B4", "Type of paper size"), QPageSize(QPageSize::B4));
+	paperSizesMap.insert(tr("B5", "Type of paper size"), QPageSize(QPageSize::B5));
+	paperSizesMap.insert(tr("B6", "Type of paper size"), QPageSize(QPageSize::B6));
+	paperSizesMap.insert(tr("B7", "Type of paper size"), QPageSize(QPageSize::B7));
+	paperSizesMap.insert(tr("B8", "Type of paper size"), QPageSize(QPageSize::B8));
+	paperSizesMap.insert(tr("B9", "Type of paper size"), QPageSize(QPageSize::B9));
+	paperSizesMap.insert(tr("B10", "Type of paper size"), QPageSize(QPageSize::B10));
+	paperSizesMap.insert(tr("C5E", "Type of paper size"), QPageSize(QPageSize::C5E));
+	paperSizesMap.insert(tr("Comm10E", "Type of paper size"), QPageSize(QPageSize::Comm10E));
+	paperSizesMap.insert(tr("DLE", "Type of paper size"), QPageSize(QPageSize::DLE));
+	paperSizesMap.insert(tr("Executive", "Type of paper size"), QPageSize(QPageSize::Executive));
+	paperSizesMap.insert(tr("Folio", "Type of paper size"), QPageSize(QPageSize::Folio));
+	paperSizesMap.insert(tr("Ledger", "Type of paper size"), QPageSize(QPageSize::Ledger));
+	paperSizesMap.insert(tr("Legal", "Type of paper size"), QPageSize(QPageSize::Legal));
+	paperSizesMap.insert(tr("Letter", "Type of paper size"), QPageSize(QPageSize::Letter));
+	paperSizesMap.insert(tr("Tabloid", "Type of paper size"), QPageSize(QPageSize::Tabloid));
+#else
 	paperSizesMap.insert(tr("A0", "Type of paper size"), QPrinter::A0);
 	paperSizesMap.insert(tr("A1", "Type of paper size"), QPrinter::A1);
 	paperSizesMap.insert(tr("A2", "Type of paper size"), QPrinter::A2);
@@ -222,6 +266,8 @@ StatisticsPrintForm::StatisticsPrintForm(QWidget *parent): QDialog(parent){
 	paperSizesMap.insert(tr("Legal", "Type of paper size"), QPrinter::Legal);
 	paperSizesMap.insert(tr("Letter", "Type of paper size"), QPrinter::Letter);
 	paperSizesMap.insert(tr("Tabloid", "Type of paper size"), QPrinter::Tabloid);
+#endif
+
 #endif
 
 	CBpaperSize=new QComboBox();
@@ -674,10 +720,10 @@ QString StatisticsPrintForm::updateHTMLprintString(bool printAll){
 	tmp+="      }\n";
 */
 	
-	//start. the "back" stuff is needed because of a qt bug (*1*). it also solve the last empty page problem.
+	//start. the "back" stuff is needed because of a qt bug (*1*). it also solves the last empty page problem.
 	tmp+="      p.back0 {\n";	//i can't to that with a class in table, because of a qt bug
 	if(CBBreak->currentIndex()==0)
-		tmp+="        font-size: "+QString::number(tablePadding->value())+"pt;\n";	//i can't do that in table, because it will also effect detailed table cells. it is not possible with a class, because of a qt bug.
+		tmp+="        font-size: "+QString::number(tablePadding->value())+"pt;\n";	//i can't do that in table, because it will also afect detailed table cells. it is not possible with a class, because of a qt bug.
 	else
 		tmp+="        font-size: 1pt;\n";	//font size 0 is not possible.
 //	tmp+="        padding-top: "+QString::number(tablePadding->value())+"px;\n";	//not possible: qt bug.
@@ -687,7 +733,7 @@ QString StatisticsPrintForm::updateHTMLprintString(bool printAll){
 	tmp+="      }\n";
 	tmp+="      p.back1 {\n";	//i can't to that with a class in table, because of a qt bug
 	if(CBBreak->currentIndex()==0 || CBBreak->currentIndex()==2)
-		tmp+="        font-size: "+QString::number(tablePadding->value())+"pt;\n";	//i can't do that in table, because it will also effect detailed table cells. it is not possible with a class, because of a qt bug.
+		tmp+="        font-size: "+QString::number(tablePadding->value())+"pt;\n";	//i can't do that in table, because it will also afect detailed table cells. it is not possible with a class, because of a qt bug.
 	else
 		tmp+="        font-size: 1pt;\n";	//font size 0 is not possible.
 //	tmp+="        padding-top: "+QString::number(tablePadding->value())+"px;\n";	//not possible: qt bug.
@@ -871,11 +917,20 @@ void StatisticsPrintForm::print(){
 	QPrinter printer(QPrinter::HighResolution);
 
 	assert(paperSizesMap.contains(CBpaperSize->currentText()));
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,2)
+	printer.setPageSize(paperSizesMap.value(CBpaperSize->currentText()));
+#else
 	printer.setPaperSize(paperSizesMap.value(CBpaperSize->currentText()));
+#endif
 
 	switch(CBorientationMode->currentIndex()){
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,2)
+		case 0: printer.setPageOrientation(QPageLayout::Portrait); break;
+		case 1: printer.setPageOrientation(QPageLayout::Landscape); break;
+#else
 		case 0: printer.setOrientation(QPrinter::Portrait); break;
 		case 1: printer.setOrientation(QPrinter::Landscape); break;
+#endif
 		default: assert(0==1);
 	}
 #if QT_VERSION >= QT_VERSION_CHECK(5,3,0)
@@ -899,7 +954,11 @@ void StatisticsPrintForm::print(){
 	if (printDialog.exec() == QDialog::Accepted) {
 		QTextDocument textDocument;
 		textDocument.documentLayout()->setPaintDevice(&printer);
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,2)
+		textDocument.setPageSize(QSizeF(printer.pageLayout().paintRectPixels(printer.resolution()).size()));
+#else
 		textDocument.setPageSize(QSizeF(printer.pageRect().size()));
+#endif
 		textDocument.setHtml(updateHTMLprintString(true));
 		textDocument.print(&printer);
 	}
@@ -915,11 +974,20 @@ void StatisticsPrintForm::printPreviewFull(){
 	QPrinter printer(QPrinter::HighResolution);
 
 	assert(paperSizesMap.contains(CBpaperSize->currentText()));
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,2)
+	printer.setPageSize(paperSizesMap.value(CBpaperSize->currentText()));
+#else
 	printer.setPaperSize(paperSizesMap.value(CBpaperSize->currentText()));
+#endif
 
 	switch(CBorientationMode->currentIndex()){
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,2)
+		case 0: printer.setPageOrientation(QPageLayout::Portrait); break;
+		case 1: printer.setPageOrientation(QPageLayout::Landscape); break;
+#else
 		case 0: printer.setOrientation(QPrinter::Portrait); break;
 		case 1: printer.setOrientation(QPrinter::Landscape); break;
+#endif
 		default: assert(0==1);
 	}
 #if QT_VERSION >= QT_VERSION_CHECK(5,3,0)
@@ -952,7 +1020,11 @@ void StatisticsPrintForm::updatePreviewFull(QPrinter* printer){
 #else
 	QTextDocument textDocument;
 	textDocument.documentLayout()->setPaintDevice(printer);
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,2)
+	textDocument.setPageSize(QSizeF(printer->pageLayout().paintRectPixels(printer->resolution()).size()));
+#else
 	textDocument.setPageSize(QSizeF(printer->pageRect().size()));
+#endif
 	textDocument.setHtml(updateHTMLprintString(true));
 	textDocument.print(printer);
 #endif
@@ -966,11 +1038,19 @@ void StatisticsPrintForm::printPreviewSmall(){
 	QPrinter printer(QPrinter::HighResolution);
 
 	assert(paperSizesMap.contains(CBpaperSize->currentText()));
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,2)
+#else
 	printer.setPaperSize(paperSizesMap.value(CBpaperSize->currentText()));
+#endif
 
 	switch(CBorientationMode->currentIndex()){
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,2)
+		case 0: printer.setPageOrientation(QPageLayout::Portrait); break;
+		case 1: printer.setPageOrientation(QPageLayout::Landscape); break;
+#else
 		case 0: printer.setOrientation(QPrinter::Portrait); break;
 		case 1: printer.setOrientation(QPrinter::Landscape); break;
+#endif
 		default: assert(0==1);
 	}
 #if QT_VERSION >= QT_VERSION_CHECK(5,3,0)
@@ -1003,7 +1083,11 @@ void StatisticsPrintForm::updatePreviewSmall(QPrinter* printer){
 #else
 	QTextDocument textDocument;
 	textDocument.documentLayout()->setPaintDevice(printer);
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,2)
+	textDocument.setPageSize(QSizeF(printer->pageLayout().paintRectPixels(printer->resolution()).size()));
+#else
 	textDocument.setPageSize(QSizeF(printer->pageRect().size()));
+#endif
 	textDocument.setHtml(updateHTMLprintString(false));
 	textDocument.print(printer);
 #endif
