@@ -984,7 +984,7 @@ void TimetableViewRoomsDaysHorizontalForm::lock(bool lockTime, bool lockSpace)
 			 "See http://doc.qt.io/qt-5/i18n-plural-rules.html for advice on how to correctly translate this field."
 			 "Also, see http://doc.qt.io/qt-5/i18n-source-translation.html, section 'Handling Plurals'."
 			 "You have two examples on how to translate this field in fet_en_GB.ts and in fet_ro.ts"
-			 "(open these files with Qt Linguist and see the translation of this field).", QCoreApplication::CodecForTr,
+			 "(open these files with Qt Linguist and see the translation of this field).", QCoreApplication::UnicodeUTF8,
 			 addedT);
 		}
 		if(addedS>0){
@@ -992,7 +992,7 @@ void TimetableViewRoomsDaysHorizontalForm::lock(bool lockTime, bool lockSpace)
 			 "See http://doc.qt.io/qt-5/i18n-plural-rules.html for advice on how to correctly translate this field."
 			 "Also, see http://doc.qt.io/qt-5/i18n-source-translation.html, section 'Handling Plurals'."
 			 "You have two examples on how to translate this field in fet_en_GB.ts and in fet_ro.ts"
-			 "(open these files with Qt Linguist and see the translation of this field).", QCoreApplication::CodecForTr,
+			 "(open these files with Qt Linguist and see the translation of this field).", QCoreApplication::UnicodeUTF8,
 			 addedS);
 		}
 		if(unlockedT>0){
@@ -1000,7 +1000,7 @@ void TimetableViewRoomsDaysHorizontalForm::lock(bool lockTime, bool lockSpace)
 			 "See http://doc.qt.io/qt-5/i18n-plural-rules.html for advice on how to correctly translate this field."
 			 "Also, see http://doc.qt.io/qt-5/i18n-source-translation.html, section 'Handling Plurals'."
 			 "You have two examples on how to translate this field in fet_en_GB.ts and in fet_ro.ts"
-			 "(open these files with Qt Linguist and see the translation of this field).", QCoreApplication::CodecForTr,
+			 "(open these files with Qt Linguist and see the translation of this field).", QCoreApplication::UnicodeUTF8,
 			 unlockedT);
 		}
 		if(unlockedS>0){
@@ -1008,7 +1008,7 @@ void TimetableViewRoomsDaysHorizontalForm::lock(bool lockTime, bool lockSpace)
 			 "See http://doc.qt.io/qt-5/i18n-plural-rules.html for advice on how to correctly translate this field."
 			 "Also, see http://doc.qt.io/qt-5/i18n-source-translation.html, section 'Handling Plurals'."
 			 "You have two examples on how to translate this field in fet_en_GB.ts and in fet_ro.ts"
-			 "(open these files with Qt Linguist and see the translation of this field).", QCoreApplication::CodecForTr,
+			 "(open these files with Qt Linguist and see the translation of this field).", QCoreApplication::UnicodeUTF8,
 			 unlockedS);
 		}
 #endif
